<?php
/** Bavarian (Boarisch)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Als-Holder
 * @author Bua333
 * @author Geitost
 * @author Malafaya
 * @author Man77
 * @author Merlissimo
 * @author Metalhead64
 * @author Mucalexx
 * @author The Evil IP address
 * @author Wikifan
 * @author bar.wikipedia.org administrators
 * @author ✓
 */

$fallback = 'de';

$namespaceNames = array(
	NS_MEDIA            => 'Media',
	NS_SPECIAL          => 'Spezial',
	NS_TALK             => 'Dischkrian',
	NS_USER             => 'Nutza',
	NS_USER_TALK        => 'Nutza_Dischkrian',
	NS_PROJECT_TALK     => '$1_Dischkrian',
	NS_FILE             => 'Datei',
	NS_FILE_TALK        => 'Datei_Dischkrian',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_Dischkrian',
	NS_TEMPLATE         => 'Vorlog',
	NS_TEMPLATE_TALK    => 'Vorlog_Dischkrian',
	NS_HELP             => 'Huif',
	NS_HELP_TALK        => 'Huif_Dischkrian',
	NS_CATEGORY         => 'Kategorie',
	NS_CATEGORY_TALK    => 'Kategorie_Dischkrian',
);

$namespaceAliases = array(
	# German namespaces
	'Medium'               => NS_MEDIA,
	'Diskussion'           => NS_TALK,
	'Benutzer'             => NS_USER,
	'Benutzer_Diskussion'  => NS_USER_TALK,
	'$1_Diskussion'        => NS_PROJECT_TALK,
	'Datei_Diskussion'     => NS_FILE_TALK,
	'MediaWiki_Diskussion' => NS_MEDIAWIKI_TALK,
	'Vorlage'              => NS_TEMPLATE,
	'Vorlage_Diskussion'   => NS_TEMPLATE_TALK,
	'Hilfe'                => NS_HELP,
	'Hilfe_Diskussion'     => NS_HELP_TALK,
	'Kategorie_Diskussion' => NS_CATEGORY_TALK,
);

$messages = array(
# User preference toggles
'tog-underline' => 'Links unterstreichen:',
'tog-justify' => 'Text ois Blocksotz',
'tog-hideminor' => 'Kloane Änderrungen ausblenden',
'tog-hidepatrolled' => 'Kontroilirde Änderrungen in dé „Létzten Änderrungen“ ausblenden',
'tog-newpageshidepatrolled' => 'Kóntróilirde Seiten auf da Listen „Neiche Seiten“ vaberng',
'tog-extendwatchlist' => 'Daweiterde Beówochtungslisten',
'tog-usenewrc' => "Daweiterde Dorstöung voh d' létzden Änderrungen (JavaScript werd braucht)",
'tog-numberheadings' => 'Ywerschriften autómaatisch nummerrirn',
'tog-showtoolbar' => 'Beorweiten-Werkzeigleisten åzoang (JavaScript werd braucht)',
'tog-editondblclick' => 'Seiten mid am Dóppedrucker beorweiden (JavaScript werd braucht)',
'tog-editsection' => "Links zum beorweiten voh d' oahzelnen Obschnitt åzoang",
'tog-editsectiononrightclick' => 'Oahzelne Obschnitt mid am Rechtsdrucker beorweiten (JavaScript werd braucht)',
'tog-showtoc' => 'Åzoang vom Inhoidsvazeichnis bei Seiten mid merer ois drei Ywerschriften',
'tog-rememberpassword' => 'Mim Browser dauerhoft ågmödt bleim (maximaal $1 {{PLURAL:$1|Toog|Toog}})',
'tog-watchcreations' => 'Voh mir söwer eihgstöde Seiten autómaatisch beówochten',
'tog-watchdefault' => 'Voh mir söwer gänderde Seiten autómaatisch beówochten',
'tog-watchmoves' => 'Voh mir söwer vaschówerne Seiten autómaatisch beówochten',
'tog-watchdeletion' => 'Voh mir söwer gléschde Seiten autómaatisch beówochten',
'tog-minordefault' => "D' eigernen Änderrungen standardmässig gringfiagig markirn",
'tog-previewontop' => 'Vurschau ówerhoib vom Beorweitungsfenster åzoang',
'tog-previewonfirst' => "Ban ersten Beorweiten oiwei d' Vurschau åzoang",
'tog-nocache' => 'Seitencache vom Browser deaktivirn',
'tog-enotifwatchlistpages' => 'Bei Änderrungen voh beówochterde Seiten a E-Mail schicken',
'tog-enotifusertalkpages' => 'Bei Änderrungen voh meiner Benutzerseiten a E-Mail schicken',
'tog-enotifminoredits' => 'Aa ba kloane Änderrungen voh beówochterde Seiten a E-Mail schicker',
'tog-enotifrevealaddr' => 'Deih E-Mail-Adress in Benoochrichtigungs-E-Mails åzoang',
'tog-shownumberswatching' => "D' Åzoi voh dé beówochterden Benutzer åzoang",
'tog-oldsig' => 'Existente Unterschrift',
'tog-fancysig' => 'Unterschrift ois Wikitext bhåndln (óne autómaatische Valinkung)',
'tog-uselivepreview' => 'Live-Vurschau nutzen (dodafyr braucht ma JavaScript) (experimentoy)',
'tog-forceeditsummary' => 'Warnen, wånn ban Speichern dé Zåmmerfossung fööd',
'tog-watchlisthideown' => 'Eigerne Beorweitungen in da Beówochtungslisten ausblenden',
'tog-watchlisthidebots' => 'Beorweitungen durch Bots in da Bówochtungslisten ausblenden',
'tog-watchlisthideminor' => 'Kloane Beorweitunger in da Bówochtungslisten ausblenden',
'tog-watchlisthideliu' => 'Beorweitunger vo ågmödte Bnutzer in da Beówochtungslisten ausblenden',
'tog-watchlisthideanons' => 'Ned ogmoidte Nutzer in da Beówochtungslisten ausblenden',
'tog-watchlisthidepatrolled' => 'Kontroilirde Änderrungen in da Beowochtungslisten ausblenden',
'tog-ccmeonemails' => 'Schick ma Kopien voh dé E-Mails, dé i åndre Benutzer send',
'tog-diffonly' => "Zoag beim Versiónsvagleich netter dé Unterschiad und néd d' voiständige Seiten",
'tog-showhiddencats' => 'Vasteckte Kategorien åzoang',
'tog-norollbackdiff' => "Unterschiad noch'm Zrucksetzen unterdrucker",
'tog-useeditwarning' => ' A Warung geem, sofern a zur da Beorweitung geffnate Seiten valossen werd, de ned gspeicherde Änderrungen enthoit.',

'underline-always' => 'oiwei',
'underline-never' => 'nia',
'underline-default' => 'obhängig voh da Browsereistöung',

# Font style option in Special:Preferences
'editfont-style' => 'Schriftoart fyrn Text im Beorweitungsfenster',
'editfont-default' => 'Browserstandard',
'editfont-monospace' => 'Schrift mid ner festen Zeichenbreaden',
'editfont-sansserif' => 'Serifenlose Groteskschrift',
'editfont-serif' => 'Schrift mid Serifen',

# Dates
'sunday' => 'Sundog',
'monday' => 'Mondog',
'tuesday' => 'Deansdog',
'wednesday' => 'Midwoch',
'thursday' => 'Dunasdog',
'friday' => 'Freidog',
'saturday' => 'Samsdog',
'sun' => 'Su',
'mon' => 'Mo',
'tue' => 'De',
'wed' => 'Mi',
'thu' => 'Du',
'fri' => 'Fr',
'sat' => 'Sa',
'january' => 'Jenna',
'february' => 'Feba',
'march' => 'Meaz',
'april' => 'Aprui',
'may_long' => 'Mai',
'june' => 'Juni',
'july' => 'Juli',
'august' => 'August',
'september' => 'Septemba',
'october' => 'Oktoba',
'november' => 'Novemba',
'december' => 'Dezemba',
'january-gen' => 'Jenna',
'february-gen' => 'Feba',
'march-gen' => 'Meaz',
'april-gen' => 'Aprui',
'may-gen' => 'Mai',
'june-gen' => 'Juni',
'july-gen' => 'Juli',
'august-gen' => 'August',
'september-gen' => 'Septemba',
'october-gen' => 'Oktoba',
'november-gen' => 'Novemba',
'december-gen' => 'Dezemba',
'jan' => 'Jen.',
'feb' => 'Feb.',
'mar' => 'Mea.',
'apr' => 'Apr.',
'may' => 'Mai',
'jun' => 'Jun.',
'jul' => 'Jul.',
'aug' => 'Aug.',
'sep' => 'Sep.',
'oct' => 'Okt.',
'nov' => 'Nov.',
'dec' => 'Dez.',

# Categories related messages
'pagecategories' => '{{PLURAL:$1|Kategorie|Kategorina}}',
'category_header' => 'Seitn in da Kategorie „$1“',
'subcategories' => 'Untakategorina',
'category-media-header' => 'Medien in da Kategorie „$1“',
'category-empty' => "''De Kategorie enthoit im Moment koane Seitn und koane Medien ned.''",
'hidden-categories' => '{{PLURAL:$1|Vasteckte Kategorie|Vasteckte Kategorina}}',
'hidden-category-category' => 'Vasteckte Kategorie',
'category-subcat-count' => '{{PLURAL:$2|De Kategorie enthoit nua de foigande Untakategorie:|{{PLURAL:$1|De foigande Untakategorie is oane vo insgsamt $2 Untakategorina in dea Kategorie:|Vo insgsamt $2 Untakategorina in dea Kategoriewean $1 zoagt:}}}}',
'category-subcat-count-limited' => 'In de Kategorie {{PLURAL:$1|is de foigande Unterkategorie|san de foiganden Unterkategorien}} eihsortird:',
'category-article-count' => '{{PLURAL:$2|De Kategorie enthoit foigande Seitn:|{{PLURAL:$1|Foigande Seitn is oane vo insgsamt $2 Seitn in dear Kategorie:|Es wern $1 voh insgsamt $2 Seitn in dea Kategorie zoagt:}}}}',
'category-article-count-limited' => 'De {{PLURAL:$1|foigande Seiten is|foiganden $1 Seiten san}} in derer Kategorie enthoiden:',
'category-file-count' => '{{PLURAL:$2|De Kategorie enthoid foigende Datei:|{{PLURAL:$1|Foigende Datei is oane vo insgsamt $2 Datein in dera Kategorie:|Es wean $1 von insgsamt $2 Datein in dera Kategorie ozoagt:}}}}',
'category-file-count-limited' => "{{PLURAL:$1|D' foingde Datei is|De foingden $1 Datein san}} in de Kategorie eisortird:",
'listingcontinuesabbrev' => '(Fortsetzung)',
'index-category' => 'Indizirde Seiten',
'noindex-category' => 'Ned-indiziade Seitn',
'broken-file-category' => 'Seiten mid kaputte Daateilinks',

'about' => 'Iba',
'article' => 'Artike',
'newwindow' => '(wean in an neichn Fensta afgmocht)',
'cancel' => 'Obbrecha',
'moredotdotdot' => 'Merer',
'mypage' => 'Eigerne Seiten',
'mytalk' => 'Mei Dischkurs',
'anontalk' => 'Dischkrirseiten voh derer IP-Adress',
'navigation' => 'Navigation',
'and' => '&#32;und',

# Cologne Blue skin
'qbfind' => 'Finden',
'qbbrowse' => 'Blaadeln',
'qbedit' => 'werkeln',
'qbpageoptions' => 'Seitenopzionen',
'qbmyoptions' => 'Meine Seiten',
'qbspecialpages' => 'Speziaalseiten',
'faq' => 'Oft gstejte Frong',
'faqpage' => 'Project:FAQ',

# Vector skin
'vector-action-addsection' => 'An Obschnitt dazua doa',
'vector-action-delete' => 'Leschn',
'vector-action-move' => 'Vaschiabm',
'vector-action-protect' => 'Schitzn',
'vector-action-undelete' => 'Wiederherstön',
'vector-action-unprotect' => 'freigeem',
'vector-simplesearch-preference' => 'Daweiterte Suachvurschläg aktivirn (netter Vector)',
'vector-view-create' => 'Aufbaun',
'vector-view-edit' => 'Werkln',
'vector-view-history' => 'Gschicht oschaugn',
'vector-view-view' => 'Lesn',
'vector-view-viewsource' => 'Quejtext ozoagn',
'actions' => 'Aktiona',
'namespaces' => 'Namasramm',
'variants' => 'Variantn',

'errorpagetitle' => 'Fehla',
'returnto' => 'Zruck za da Seitn $1.',
'tagline' => 'Aus {{SITENAME}}',
'help' => 'Huif',
'search' => 'Suach',
'searchbutton' => 'Suacha',
'go' => 'Ausfyrn',
'searcharticle' => 'Artikl',
'history' => 'Versiona',
'history_short' => 'Gschicht oschaugn',
'updatedmarker' => '(gänderd)',
'printableversion' => 'Druckversion',
'permalink' => 'Permanenta Link',
'print' => 'Drucken',
'view' => 'Leesen',
'edit' => 'Werkln',
'create' => 'Aufbaun',
'editthispage' => 'Seiten beorweiten',
'create-this-page' => 'Seiten erstön',
'delete' => 'Leschn',
'deletethispage' => 'De Seiten leschen',
'undelete_short' => '{{PLURAL:$1|1 Version|$1 Versionen}} wiederherstön',
'viewdeleted_short' => '{{PLURAL:$1|Oah geléschde Versión|$1 geléschde Versiónen}} åschauh',
'protect' => 'Schitzn',
'protect_change' => 'endan',
'protectthispage' => 'Seiten schytzen',
'unprotect' => 'freigeem',
'unprotectthispage' => 'Seitenschutz ändern',
'newpage' => 'Neiche Seitn',
'talkpage' => 'De Seiten bsprecher',
'talkpagelinktext' => 'Dischkrian',
'specialpage' => 'Speziaalseiten',
'personaltools' => 'Mei Werkzeig',
'postcomment' => 'Neicher Obschnit',
'articlepage' => 'Seiteninhoid åzoang',
'talk' => 'Dischkrian',
'views' => 'Osichtn',
'toolbox' => 'Werkzeigkisten',
'userpage' => 'Benutzerseiten',
'projectpage' => 'Projektseiten åzoang',
'imagepage' => 'Daateiseiten åzoang',
'mediawikipage' => 'Inhoitsseiten åzoang',
'templatepage' => 'Vurlongseiten åzoang',
'viewhelppage' => 'Hüfeseiten åzoang',
'categorypage' => 'Kategorieseiten åzoang',
'viewtalkpage' => 'Diskussion',
'otherlanguages' => 'Andane Sprochn',
'redirectedfrom' => '(Weidagloadt vo $1)',
'redirectpagesub' => 'Weiderloatung',
'lastmodifiedat' => 'De Seitn is zletzt am $1 um $2 gendad worn.',
'viewcount' => 'Dé Seiten do is bis iatz {{PLURAL:$1|oahmoi|$1-moi}} obgruaffm worn.',
'protectedpage' => 'Gschytzde Seiten',
'jumpto' => 'Wexln za:',
'jumptonavigation' => 'Navigation',
'jumptosearch' => 'Suach',
'view-pool-error' => "Tschuidige, dé Server san im Moment ywerlostt.
Zvü Leid vasuachen, dé Seiten do z' bsuachen.
Bittscheh wort a por Minuten, bevur du 's nohamoi vasuachst.

$1",
'pool-timeout' => "Zeidoblaaff beim Worten auf d' Sperrung",
'pool-queuefull' => 'Poolworteschlång is vói',
'pool-errorunknown' => 'Unbekånnter Feeler',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage).
'aboutsite' => 'Iba {{SITENAME}}',
'aboutpage' => 'Project:Iba',
'copyright' => 'Da Inhoid is unter da $1 vafiagbor.',
'copyrightpage' => '{{ns:project}}:Urhebarecht',
'currentevents' => 'Aktuelle Ereigniss',
'currentevents-url' => 'Project:Aktuelle Ereigniss',
'disclaimers' => 'Impressum',
'disclaimerpage' => 'Project:Impressum',
'edithelp' => 'Huif fias Werkln',
'helppage' => 'Help:Inhoidsvazeichnis',
'mainpage' => 'Hoamseitn',
'mainpage-description' => 'Hoamseitn',
'policy-url' => 'Project:Richtlinien',
'portal' => 'Autornportal',
'portal-url' => 'Project:Autornportal',
'privacy' => 'Datnschutz',
'privacypage' => 'Project:Datnschutz',

'badaccess' => 'Koane ausreichenden Rechtt',
'badaccess-group0' => "Du host néd d' daforderliche Berechtigung fyr dé Akzión do.",
'badaccess-groups' => 'Dé Akzión is bschränkt auf Benutzer, dé {{PLURAL:$2|da Gruppm|oahne voh dé Gruppm}} „$1“ åghern.',

'versionrequired' => 'Versión $1 voh MediaWiki werd braucht.',
'versionrequiredtext' => "Versión $1 voh MediaWiki werd braucht, um dé Seiten nützen z' kenner.
Schaug auf [[Special:Version|Versiónsseiten]]",

'ok' => 'Passt',
'retrievedfrom' => 'Vh „$1“',
'youhavenewmessages' => 'Du host $1 ($2).',
'newmessageslink' => 'neiche Nochrichtn',
'newmessagesdifflink' => 'Letzte Endarung',
'youhavenewmessagesmulti' => 'Du host neiche Nochrichtn: $1',
'editsection' => 'Werkln',
'editold' => 'Werkln',
'viewsourceold' => 'Quejtext ozoagn',
'editlink' => 'werkln',
'viewsourcelink' => 'In Quejtext ozoagn',
'editsectionhint' => 'Obschnitt beorbatn: $1',
'toc' => 'Inhoidsvazeichnis',
'showtoc' => 'Åzoang',
'hidetoc' => 'vastecken',
'collapsible-collapse' => 'Eihkloppm',
'collapsible-expand' => 'Auskloppm',
'thisisdeleted' => '$1 åschauh óder wiederherstön?',
'viewdeleted' => '$1 åzoang?',
'restorelink' => '$1 gléschde {{PLURAL:$1|Versión|Versiónen}}',
'feedlinks' => 'Feed:',
'feed-invalid' => 'Néd gütiger Feed-Abonnement-Typ.',
'feed-unavailable' => 'Es steengern koane Feeds zur Vafiagung.',
'site-rss-feed' => 'RSS-Feed fyr $1',
'site-atom-feed' => 'Atom-Feed fia $1',
'page-rss-feed' => 'RSS-Feed fyr „$1“',
'page-atom-feed' => 'Atom-Feed fia „$1“',
'red-link-title' => '$1 (de Seitn gibts ned)',
'sort-descending' => 'Obsteigend sortiern',
'sort-ascending' => 'Aufsteigend sortiern',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Seitn',
'nstab-user' => 'Nutzaseitn',
'nstab-media' => 'Meedienseiten',
'nstab-special' => 'Spezialseitn',
'nstab-project' => 'Projektseitn',
'nstab-image' => 'Datei',
'nstab-mediawiki' => 'Systémnoochricht',
'nstab-template' => 'Vorlog',
'nstab-help' => 'Hüfeseiten',
'nstab-category' => 'Kategorie',

# Main script and global functions
'nosuchaction' => 'De Akzion gibts ned',
'nosuchactiontext' => 'Dé in da URL ågeewerne Akzión werd voh MediaWiki néd unterstytzd.
Es kå a Schreibfeeler in da URL vurlieng óder es is a feelerhofter Link åklickt worn.
Es kå sé aa um an Prógrammierfeeler in da Software, dé auf {{SITENAME}} bnutzd werd, håndeln.',
'nosuchspecialpage' => 'De Speziaalsaiten gibts ned',
'nospecialpagetext' => "<strong>Dé aufgruafferne Speziaalseiten is néd vurhånden.</strong>

Olle vafiagborn Speziaalseiten san in da [[Special:SpecialPages|Listen voh dé Speziaalseiten]] z' finden.",

# General errors
'error' => 'Feeler',
'databaseerror' => 'Feeler in da Daatenbånk',
'laggedslavemode' => "'''Ochtung:''' De åzoagte Seiten kunnterd unter Umständ ned d' letzden Beorweitungen enthoiden.",
'readonly' => 'Daatenbånk gsperrd',
'enterlockreason' => 'Bittscheh gib an Grund å, warum de Daatenbånk gsperrd wern soi und a Obschätzung ywer de Dauer voh da Sperrung',
'readonlytext' => 'De Daatenbånk is vurywergeehend fyr Neieihtreeg und Änderrungen gsperrd. Bittschee vasuchs spaader nuamoi.

Grund voh da Sperrung: $1',
'missing-article' => 'Da Text vo „$1“ $2 is in da Daatenbank ned gfundn worn.

De Seitn is meglicherwei gleschd oda vaschobm worn.

Fois des ned zuatrifft, hosd eventuell an Fehla im Programm gfundn. Bittschee informia an [[Special:ListUsers/sysop|Administrator]] und nenn eam de URL.',
'missingarticle-rev' => '(Versionsnumma: $1)',
'missingarticle-diff' => '(Unterschiad zwischen Versionen: $1, $2)',
'readonly_lag' => "De Daatenbånk is automaatisch fyr Schraibzuagriff gsperrt, damid se d' vatailten Daatenbånkserver (slaves) mim Hauptdaatenbånkserver (master) obglaichen kennan.",
'internalerror' => 'Interner Feeler',
'internalerror_info' => 'Interner Feeler: $1',
'fileappenderrorread' => '"$1" hod wärend \'m dazuafyng ned gleesen wern kenna.',
'fileappenderror' => 'Dé Daatei „$1“ hod néd noch „$2“ kopird wern kenner.',
'filecopyerror' => 'De Datai „$1“ hod ned noch „$2“ kopird wern kenna.',
'filerenameerror' => 'Dé Daatei „$1“ hod néd noch „$2“ umbenånnt wern kenner.',
'filedeleteerror' => 'De Daatei „$1“ hod néd gléschd wern kenner.',
'directorycreateerror' => 'As Vazeichnis „$1“ hod néd åglégt wern kenner.',
'filenotfound' => 'Dé Daatei „$1“ is néd gfunden worn.',
'fileexistserror' => "In d' Daatei „$1“ hod néd gschriem wern kenner, weils dé Daatei nämlé schå gibt.",
'unexpected' => 'Unerworteder Wert: „$1“=„$2“.',
'formerror' => 'Feeler: Dé Eihgom håm néd vaorweitt wern kenner.',
'badarticleerror' => 'Dé Akzión kå néd auf dé Seiten ågwendt wern.',
'cannotdelete' => 'Dé Seiten óder Daatei "$1" kå néd gléschd wern.
Méglicherweis iss schoh vohram åndern gléschd worn.',
'cannotdelete-title' => 'Seiten „$1“ kå néd gléschd wern',
'badtitle' => 'koa gitiga Titl',
'badtitletext' => 'Da Titl voh da ogfordatn Seitn is ned gitig, laar oda a ungitiga Sprochlink vonam andan Wiki.',
'perfcached' => "Dé fóigernden Daaten staummern aus'm Cache und san méglicherweis nimmer aktuö. Maximoi {{PLURAL:$1|oah Ergebnis is|$1 Ergebniss san}} im Cache vafiagbor.",
'perfcachedts' => "Dé Daaten staummern aus 'm Cache. Da Zeidbunkt voh da létzden Aktualisiarung: $1. Maximoi {{PLURAL:$4|oah Ergebnis is|$4 Ergebniss san}} im Cache vafiagbor.",
'querypage-no-updates' => "'''Dé Aktualisiarungsfunkzión voh derer Seiten is derzeid deaktivird. Dé Daaten wern bis auf Weiders néd daneiert.'''",
'wrong_wfQuery_params' => 'Foische Parameeter fyr wfQuery()<br />
Funkzión: $1<br />
Obfrog: $2',
'viewsource' => 'Quejtext ozoagn',
'viewsource-title' => 'Quöntext voh da Seiten $1 auhschauh',
'actionthrottled' => 'Akziónszoi limitird',
'actionthrottledtext' => 'Im Råmen voh ner Anti-Spam-Moossnåm kå dé Akzión do in am kurzen Zeidobstånd netter begrenzd ausgfyrd wern. Dé Grenzen host ywerschritten.
Bittscheh vasuachs in a por Minunten nuamoi.',
'protectedpagetext' => "Dé Seiten is gschytzd worn, um Beorweitungen z' vahindern.",
'viewsourcetext' => "Du kåst ower 'n Quötext åschaung und kópirn:",
'viewyourtext' => "Du kåst 'n Quejtext vah '''deiner Beorwatung''' derer Seiten betrochten und kópiern:",
'protectedinterface' => "Dé Seiten do enthoit Text fyr d' Benutzerówerflächen voh da Software und is gschytzd, um an Missbrauch vurzbeing.",
'editinginterface' => "'''Ówocht:''' Dé Seiten do enthoit voh da MediaWiki-Software gnutzden Text. 
Änderrungen auf derer Seiten wirken sé auf d' Benutzerówerflächen aus.
Ziag bittscheh im Foi voh Ywersétzungen in Betrocht, dé bei [//translatewiki.net/wiki/Main_Page?setlang=de translatewiki.net], da Lókaalisiarungsblottform fyr MediaWiki, durchzfyrn.",
'cascadeprotected' => "Dé Seiten is zua da Beorweitung gsperrd worn. Sie is in d' {{PLURAL:$1|fóigande Seiten|fóiganden Seiten}} eihbunden, dé mid da Kaskaadensperrópzión gschytzd {{PLURAL:$1|is|san}}:
$2",
'namespaceprotected' => "Du host néd d' daforderliche Berechtigung, Seiten im Náumensraum '''$1''' b'orweiden z' kenner.",
'customcssprotected' => "Du host néd d' Berechtigung dé CSS enthoitende Seiten z' b'orweiden, weis d' persénlichen Eihstöungen vohram aundern Benutzer enthoitt.",
'customjsprotected' => "Du host néd d' Berechtigung dé JavaScript enthoitende Seiten z' b'orweiden, weis d' persénlichen Eihstöungen vohram aundern Benutzer enthoitt.",
'ns-specialprotected' => "Speziaalseiten kennern néd b'orweidt wern.",
'titleprotected' => "A Seiten mid dém Nåm kå néd åglégd wern. Dé Sperrn is durch [[User:$1|$1]] mid da Begryndung ''„$2“'' eihgerichtt worn.",

# Virus scanner
'virus-badscanner' => "Feelerhofte Kónfigurazión: unbekaunnter Virnscanner: ''$1''",
'virus-scanfailed' => 'Scan is föögschlong (code $1)',
'virus-unknownscanner' => 'Néd bekaunnter Virnscanner:',

# Login and logout pages
'logouttext' => "'''Iatzerd bist obgmödt.'''

Du kåst {{SITENAME}} iatzerd anónym weiderdoah, óder di danaid unterm söwing óder am åndern Benutzernåm <span class='plainlinks'>[$1 åmöden]</span>.
Beochtt ower, daas oanige Seiten noh åzoang kennern, daas du ågmödt bist, sólång du néd deih Browsercache glaard host.",
'yourname' => 'Nutzanama:',
'yourpassword' => 'Passwort:',
'yourpasswordagain' => 'Es Passwort no amoi eigebm',
'remembermypassword' => 'Mitm Brausa dauahoft ogmejd bleibm (maximoi $1 {{PLURAL:$1|Dog|Dog}})',
'yourdomainname' => 'Eanerne Domain:',
'externaldberror' => 'Entweder es ligt a Feeler bai da externen Authentifiziarung vur oder du derfst dai externs Benytzerkonto ned aktualisirn.',
'login' => 'Eilogga',
'nav-login-createaccount' => 'Eilogga / Konto olegn',
'loginprompt' => 'Zua Omejdung miassen Cookies aktiviat sei.',
'userlogin' => 'Eilogga / Konto olegn',
'userloginnocreate' => 'Åmöden',
'logout' => 'Obmöden',
'userlogout' => 'Auslogga',
'notloggedin' => 'Ned ågmödt',
'nologin' => 'Du host koa Nutzakonto? $1.',
'nologinlink' => 'A neichs Nutzakonto olegn',
'createaccount' => 'Nutzakonto olegn',
'gotaccount' => "Hosd scho a Nutzakonto? '''$1'''.",
'gotaccountlink' => 'Omejdn',
'userlogin-resetlink' => 'Hosd de Datn zan Eilogga vagessn?',
'createaccountmail' => 'per E-Mail',
'createaccountreason' => 'Grund',
'badretype' => 'De zwoa Posswerter stimmer ned ywereih.',
'userexists' => 'Der Benutzernaum do is schoh vageem. Bittscheh nimm an aundern her.',
'loginerror' => 'Feeler bei da Åmödung',
'createaccounterror' => 'Des Benutzerkonto hod ned erstöd wern kenner: $1',
'nocookiesnew' => "Da Benytzerzuagång is erstöid worn, du bist ower ned ågmöidt. {{SITENAME}} benedigt fyr de Funkzion Cookies, bittschee aktiviar de und möidt de danoch mid daim naichn Benytzernåm und 'm dazuaghering Posswort å.",
'nocookieslogin' => '{{SITENAME}} nimmt Cookies zum Ailoggen vo de Benytzer her. Du host Cookies deaktivird, bittschee aktivir de und vasuchs nuamoi.',
'nocookiesfornew' => "Dés Benutzerkóntó is néd erstöd worn, wei d' Daatenherkumft néd damittelt wern hod kenner.
Es muass sichergstöd seih, daas Cookies aktivierd san. Danoch bittscheh d' Seiten daneit loon und wieder vasuacher.",
'noname' => 'Du muasst an gyting Benutzernåm ågeem.',
'loginsuccesstitle' => "D' Åmöidung is erfoigraich gween",
'loginsuccess' => 'Du bist jetzad ois „$1“ bai {{SITENAME}} ågmöidt.',
'wrongpassword' => 'Des Posswort is foisch! Bitschee prowirs nuamoi.',
'wrongpasswordempty' => 'Es is koa Posswort ned aigeem worn. Bittschee prowirs nuamoi.',
'mailmypassword' => 'Neichs Passwort zuaschicka',
'passwordremindertitle' => 'Naichs Posswort fyra {{SITENAME}}-Benytzerkonto',
'acct_creation_throttle_hit' => 'Du host scho $1 {{PLURAL:$1|Benytzerkonto|Benytzerkonten}} und kååst jetzad koane mer åleeng.',
'emailconfirmlink' => 'E-Póst-Adressen bstäting (Authentifiziarung)',
'accountcreated' => 'Benytzerkonto is erstöid worn',
'accountcreatedtext' => "'s Benytzerkonto $1 is aigrichtt worn.",
'loginlanguagelabel' => 'Sproch: $1',

# Change password dialog
'resetpass' => 'Posswort ändern',
'oldpassword' => 'Oids Posswort:',
'newpassword' => 'Neichs Posswort:',
'retypenew' => 'Neichs Posswort (nuamoi):',
'resetpass_submit' => 'Posswort ywermitteln und auhmöden',
'resetpass-submit-loggedin' => 'Posswort ändern',
'resetpass-submit-cancel' => 'Obbrechen',

# Special:PasswordReset
'passwordreset' => 'Passwoat zrucksetzn',
'passwordreset-username' => 'Benutzernåm:',

# Edit page toolbar
'bold_sample' => 'Fetta Text',
'bold_tip' => 'Fetta Text',
'italic_sample' => 'Kursiva Text',
'italic_tip' => 'Kursiva Text',
'link_sample' => 'Link-Text',
'link_tip' => 'Interna Link',
'extlink_sample' => 'http://www.example.com Link-Text',
'extlink_tip' => 'Externa Link (http:// beochtn)',
'headline_sample' => 'Ibaschrift Text',
'headline_tip' => 'Ebane-2-Ibaschrift',
'nowiki_sample' => 'Nedformatiadn Text do eibaun',
'nowiki_tip' => 'Wiki-Format ignorian',
'image_tip' => 'Dateilink',
'media_tip' => 'Datei-Link',
'sig_tip' => 'Dei Untaschrift mit Zeitstempe',
'hr_tip' => 'Wogrechte Linie (sporsam vawendn)',

# Edit pages
'summary' => 'Zammfossung:',
'subject' => 'Bedreff',
'minoredit' => 'Nua Kloanigkeidn san vaendat worn',
'watchthis' => 'De Seitn beobochtn',
'savearticle' => 'Seitn speichan',
'preview' => 'Vorschau',
'showpreview' => 'Vorschau zoagn',
'showdiff' => 'Endarunga zoagn',
'anoneditwarning' => 'Obocht: Du bist ned eigloggt.
Dei IP-Adress wead in da Versionsgschicht afzoachnet.',
'missingsummary' => "'''Hiwais:''' du host koa Zåmmfossung ågeem. Wånn du ernait auf „{{int:savearticle}}“ druckst, werd dai Enderung one a Zåmmfossung ywernumma.",
'missingcommenttext' => 'Bittschee gib a Zåmmfossung ai.',
'summary-preview' => 'Vurschau vo da Zåmmfossung:',
'subject-preview' => 'Vurschau vom Bedreff:',
'blockedtitle' => 'Da Benytzer is gsperrt',
'whitelistedittext' => "Du muasst de $1, um Saiten beorwaiten z' kenna.",
'loginreqtitle' => "'s braucht a Åmöidung",
'loginreqlink' => 'åmöden',
'loginreqpagetext' => "Du muasst dé $1, daas d' Seiten leesen kauhst.",
'accmailtitle' => 'Passwort is vaschickt worn',
'accmailtext' => 'E zuafällig genariards Posswort fyr [[User talk:$1|$1]] is an $2 gschickt worn.

Des Posswort fyr des naiche Benutzerkonto kå auf da Speziaalseiten  „[[Special:ChangePassword|Posswort ändern]]“ gändert wern.',
'newarticle' => '(Neich)',
'newarticletext' => 'Du bist am Link gfoigt, wos no koa Seitn gibt.
Um de Seitn ozlegn, trog dein Text im untan Kostn ei (schaug af da [[{{MediaWiki:Helppage}}|Huifeseitn]] fia mea Infos).
Wens a Irrtum is, dassd do bist, nach druck in Zruck-Knopf vom Brausa.',
'anontalkpagetext' => "---- ''De Seiten werd dodazua hergnumma, am ned-ågmöiderten Benutzer Nochrichten z' hinterlossen.
Wånnst mid de Kommentare auf derer Seiten nix åfanga kåst, is vamuatlich da friarerne Inhower vo derer IP-Adress gmoat und du kåstas ignorirn.
Wånnst a anonymer Benutzer bist und denkst, das irrelevante Kommentare ån di grichtt worn san, [[Special:UserLogin|möid de bittschee å]], um zuakynfteg Vawirrung z' vamein.''",
'noarticletext' => 'De Seitn enthoid momentan koan Text ned.
Du konst [[Special:Search/{{PAGENAME}}|nochm Titl]] in andan Seitn suacha,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} de Logbiacha duachsuacha],
oda [{{fullurl:{{FULLPAGENAME}}|action=edit}} de Seitn beorbatn]</span>.',
'noarticletext-nopermission' => 'Af dea Seitn gibts zua Zeit koan Text.
Du konst [[Special:Search/{{PAGENAME}}|in Seitntitl]] in andan Seitn suacha, oda <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} dia de Logbiachln dazua oschaugn]</span>, oba du hosd koa Berechtigung de Seitn ozlegn.',
'userpage-userdoesnotexist' => 'Des Benutzerkonto „<nowiki>$1</nowiki>“ is ned vurhånden. Bittschee priaf, ob du de Seiten wirkle erstöin/beorweiten wüist.',
'userpage-userdoesnotexist-view' => 'Benutzerkonto „$1“ existiard ned.',
'blocked-notice-logextract' => "{{GENDER:$1|Der Benutzer|De Benutzarin|Der Benutzer do}} is zurzeid gesperrd.
Zua da Informazion foigt a aktueller Auszug aus 'm Benutzersperr-Logbiache:",
'updated' => '(Gänderd)',
'note' => "'''Hihweis:'''",
'previewnote' => "'''Des is nua a Vorschau, de Seitn is no ned gspeichad worn!'''",
'previewconflict' => "Dé Vurschau gibt 'n Inhoid vom ówern Textföd wieder. Só werd d' Seiten ausschaung, wånnst iatz speichern duast.",
'session_fail_preview' => "'''Daine Beorwaitungen håm ned gspaichert wern kenna, wail Sitzungsdaaten valurn gånga san.'''
Bittschee vasuachs nuamoi, indem du unter da foiganden Textvurschau noamoi auf „Saiten spaichern“ druckst.
Soidad des Probleem bestee blaim, [[Special:UserLogout|möid de ob]] und danoch wider å.",
'editing' => 'Beorbatn vo $1',
'editingsection' => 'Werkln ba $1 (Obschnitt)',
'editingcomment' => 'Werkeln voh $1 (Neicher Obschnit)',
'editconflict' => 'Konflikt baim Beorwaiten: $1',
'explainconflict' => "Eppern ånderer hod de Saitn gendert, nochdem du ågfånga host de zum beorwaiten.
Des owere Textföidl enthoit 'n aktuöin Stånd.
Des untare Textföidl enthoit daine Enderungen.
Bittschee fiag daine Enderungen ins owere Textföidl ai.
'''Netter''' da Inhoit vom owern Textföidl werd gspaichert, wånn du auf  „{{int:savearticle}}“ druckst!",
'yourtext' => 'Deih Text',
'storedversion' => 'Gespeicherde Versión',
'editingold' => "'''Ochtung: Du beorwaitst a oide Version vo derer Saiten. Wånn du spaichertst, wern olle naichen Versionen ywerschriim!'''",
'copyrightwarning' => "'''Bittschee kopiar koane Websaiten, dé néd daine oaganen san, benytz koane urhéwerrechtléch gschytzten Werke óne aner Dalaabnis vom Urhéwer!'''<br />

Du gibst uns dodamid dai Zuasog, dass du dén Text '''söiwer vafosst''' host, das da Text a Oigmoaguat '''(public domain)''' is, óder das da '''Urhéwer''' sai '''Zuastimmung''' geem hod. Fois der Text beraits irngdwó ånderst vaéffmtlécht worn is, moch bittschee an Hiwais in da Diskussiónssaitn.
<i>Bittschee beochtt, das olle {{SITENAME}}-Baitrég autómaatésch unter da „$2“ steengan (schau unter $1 fyr Details). Fois du néd mechst, das dai Orwait do vo ånderne vaéndert und vabroatt werd, dånn druck néd auf „Saiten spaichern“.</i>",
'copyrightwarning2' => "Bittscheh beocht, daas olle Beiträg zua {{SITENAME}} voh ånderne Midwirkende beorweitt, gänderd óder gléscht wern kennern.
Reich do koane Textt eih, fois du néd wüst, daas dé óne Eihschränkung gänderd wern kennern.

Du bstätigst dodamid aa, daas du dé Textt söwer gschriem host óder dé voh ner gmoahfrein Quön kópird host
(schaug $1 fyr weiderne Details). '''YWERTROG ÓNE A DALAABNIS KOANE URHÉWERRECHTLICH GSCHYTZDE INHOITE!'''",
'semiprotectedpagewarning' => "'''Hoibsperrung:''' De Saiten is aso gsperrt worn, das netter registriarde Benytzer de endern kenna.",
'titleprotectedwarning' => "'''Ochtung: De Saitenerstöiung is aso gschytzt worn, das netter Benytzer mid [[Special:ListGroupRights|speziöie Rechte]] de Saiten erstöin kennan.'''
Zur Informazion foigt da aktuöie Logbuachaitrog:",
'templatesused' => '{{PLURAL:$1|De foigande Vorlog wead|De foigandn Vorlogn wean}} af dera Seitn vawendt:',
'templatesusedpreview' => "{{PLURAL:$1|De foigande Vurlog werd|D' foiganden Vurlong wern}} in derer Saiten-Vurschau vawendt:",
'templatesusedsection' => '{{PLURAL:$1|Dé fóigende Vurlog werd|Fóigende Vurlong wern}} voh dém Obschnit vawendt:',
'template-protected' => '(schreibgschitzt)',
'template-semiprotected' => '(schreibgschitzt fia ned-ogmejdte Nutza)',
'hiddencategories' => 'De Seitn is in {{PLURAL:$1|a vasteckde Kategorie|$1 vasteckde Kategorina}} eisortiad:',
'nocreate-loggedin' => "Du host koah Berechtigung, neiche Seiten z' erstön.",
'permissionserrors' => 'Berechtigungsfeeler',
'permissionserrorstext' => 'Du bist néd berechtigt, dé Akzión auszfyrn.  {{PLURAL:$1|Grund|Grynd}}:',
'permissionserrorstext-withaction' => 'Du host koa Berechtigung ned, dass de $2.
{{PLURAL:$1|Grund|Grind}}:',
'recreate-moveddeleted-warn' => "'''Obocht: Du legst a Seitn o, wo scho friaa glescht worn is.'''

Bittschee ibaleg da genau, obs sinnvoi is de Seitn ozlegn.
Des Lesch- und Vaschiab-Logbuach dazua findsd do:",
'moveddeleted-notice' => 'De Seitn do is glescht worn. Es foigt a Auszug ausm Lesch- und Vaschiabungs-Logbuch vo dea Seitn.',
'edit-conflict' => 'Konflikt ban Beorwaten.',
'editwarning-warning' => "'s Valossen vo derer Seiten kå dodazua fyrn, daas d' Änderrungen valurn geengan.
Ois ågmödter Benutzer kå's Åzoang vo derer Warnung im \"Beorweiten\"-Bereich vo de Eistellungen obgschoiden wern.",

# Parser/template warnings
'post-expand-template-inclusion-warning' => 'Obocht: De Gress vo eibundne Vorlong is z gross.
A poar Vorlogn wean ned eibundn.',
'post-expand-template-inclusion-category' => 'Seitn, wo d Gress vo de eibundnan Vorlogn ibaschrittn is',
'post-expand-template-argument-warning' => "'''Obocht:''' De Seitn enthoit mindastns oa Argument in da Vorlog, wo expandiat z grouss is. 
De Parameta wean ignoriad.",
'post-expand-template-argument-category' => 'Seiten, dé ignorirde Vurlongargumentt enthoiden',

# "Undo" feature
'undo-summary' => 'Änderrung $1 voh [[Special:Contributions/$2|$2]] ([[User talk:$2|Diskussión]]) ryckgängig gmocht.',

# Account creation failure
'cantcreateaccounttitle' => 'Benutzerkonto kå ned erstöd wern',

# History pages
'viewpagelogs' => 'Logbiacha fia de Datei ozoagn',
'currentrev' => 'Aktuelle Versión',
'currentrev-asof' => 'Letzte Version vo $1',
'revisionasof' => 'Version vom $1',
'revision-info' => 'Version vom $1 vo $2.',
'previousrevision' => '← Nextejtane Version',
'nextrevision' => 'Neiare Version →',
'currentrevisionlink' => 'Aktuelle Version',
'cur' => 'Aktuell',
'next' => 'Naxte',
'last' => 'Friaare',
'page_first' => 'Auhfaung',
'page_last' => 'End',
'histlegend' => 'Zua Ozoag vo de Endarunga oafoch de z vagleichandn Versiona und Schoitflechn „{{int:compareselectedversions}}“ druckn.<br />
* ({{int:cur}}) = Unterschied zua aktuelln Version, ({{int:last}}) = Unterschied zua vorherign Version
* Uhrzeid/Datum = Version za dera Zeid, Nutzanama/IP-Adress vom Beorbata, {{int:minoreditletter}} = Kloane Endarung',
'history-fieldset-title' => 'Suach in da Versionsgschicht',
'history-show-deleted' => 'Nua gleschte Versiona',
'histfirst' => 'Ejtaste',
'histlast' => 'Neiaste',
'historyempty' => '(laar)',

# Revision feed
'history-feed-title' => 'Versiónsgschicht',
'history-feed-item-nocomment' => '$1 am $2',
'history-feed-empty' => "Die angeforderte Seitn gibt's net.
Vielleicht is sie gelöscht oda verschom worn.
[[Special:Search|Durchsuachan]] S' {{SITENAME}} für passende neie Seitn.",

# Revision deletion
'rev-deleted-text-permission' => '<div class="mw-warning plainlinks"> De Version is glöscht worn und is nimma öffentlich zum einseng.
Nähere Angaben zum Löschvorgang sowia a Begründung findn si im [{{fullurl:{{#Special:Log}}/suppress|page={{PAGENAMEE}}}} Lösch-Logbuch].</div>',
'rev-deleted-text-view' => "Dé Versión dodan is '''gléscht''' worn.
Du kauhstas auhschauh, waunn du wüst. Nahernte Auhgoom steengern im [{{fullurl:{{#special:Log}}/delete|page={{FULLPAGENAMEE}}}} Lésch-Logbiaché].",
'rev-deleted-no-diff' => '<div class="mw-warning plainlinks">Du kannst diesen Unterschied nicht betrachten, da eine der Versionen aus den öffentlichen Archiven entfernt wurde.
Details stehen im [{{fullurl:{{#Special:Log}}/suppress|page={{FULLPAGENAMEE}}}} Lösch-Logbuch].</div>',
'rev-delundel' => 'zoagn / vastecka',
'revdelete-nooldid-title' => 'Koa Version ogem',
'revdelete-text' => "'''Der Inhalt oder andere Bestandteile gelöschter Versionen sind nicht mehr öffentlich einsehbar, erscheinen jedoch weiterhin als Einträge in der Versionsgeschichte.'''
{{SITENAME}}-Administratoren können den entfernten Inhalt oder andere entfernte Bestandteile weiterhin einsehen und wiederherstellen, es sei denn, es wurde festgelegt, dass die Zugangsbeschränkungen auch für Administratoren gelten.",
'revdel-restore' => 'Siachtborkeit endan',
'revdel-restore-deleted' => 'gleschte Versiona',
'revdel-restore-visible' => 'sichtbore Versiona',
'pagehist' => 'Versiónsgschicht',
'deletedhist' => 'Gléschde Versiónen',

# Merge log
'revertmerge' => 'Vaoanigung zruckdoa',
'mergelogpagetext' => "Des is s'Logbuach vu de vareinigtn Versionsgschichtn.",

# Diffs
'history-title' => 'Gschicht vo „$1“ oschaugn',
'lineno' => 'Zein $1:',
'compareselectedversions' => 'Ausgwejde Versiona vagleicha',
'editundo' => 'zruck doa',
'diff-multi' => '({{PLURAL:$1|A dazwischnliegade Version|$1 dazwiscenliegade Versiona}} {{PLURAL:$2|vonam Nutza|vo $2 Nutzan}} {{PLURAL:$1|wead|wean}} ned ozoagt)',

# Search results
'searchresults' => 'Suachergebniss',
'searchresults-title' => 'Suacheagebniss fia „$1“',
'searchresulttext' => "Fia weidare Infos üwa's Suacha schau auf'd [[{{MediaWiki:Helppage}}|Hüifeseitn]].",
'searchsubtitle' => 'Dei Suachãnfråg: „[[:$1|$1]]“ ([[Special:Prefixindex/$1|ålle Seitn, de mid „$1“ ãnfãngan]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|ålle Seitn, de wås nåch „$1“ valinkn]])',
'searchsubtitleinvalid' => 'Dei Suachãnfråg: „$1“.',
'notitlematches' => 'Koane Üwareinstimmungen mid de Seitntitl',
'notextmatches' => 'Ka Üwareinstimmung mid dem Inhåit gfundn',
'prevn' => '{{PLURAL:$1|vorheriga|vorherige $1}}',
'nextn' => '{{PLURAL:$1|naxta|naxte $1}}',
'prevn-title' => '{{PLURAL:$1|Vorherigs Ergebnis|Vorherige $1 Ergebniss}}',
'nextn-title' => '{{PLURAL:$1|Foilgends Ergebnis|Foigende $1 Ergebniss}}',
'shown-title' => 'Zoag $1 {{PLURAL:$1|Ergebnis|Ergebniss}} pro Seitn',
'viewprevnext' => 'Zoag ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-exists' => "'''Es gibt a Seiten, wo „[[:$1]]“ hoasst.'''",
'searchmenu-new' => "'''De Seitn „[[:$1]]“ in em Wiki eastejn.'''",
'searchprofile-articles' => 'Inhoidsseitn',
'searchprofile-project' => 'Huif- und Projektseitn',
'searchprofile-images' => 'Muitimedia',
'searchprofile-everything' => 'Ollas',
'searchprofile-advanced' => 'Daweitad',
'searchprofile-articles-tooltip' => 'Suacha in $1',
'searchprofile-project-tooltip' => 'Suacha in $1',
'searchprofile-images-tooltip' => 'Noch Datein suacha',
'searchprofile-everything-tooltip' => 'In gsamtn Inhoid duachsuacha (inkl. Dischkriaseitn)',
'searchprofile-advanced-tooltip' => 'Suach in weidna Namasramm',
'search-result-size' => '$1 ({{PLURAL:$2|1 Wort|$2 Weata}})',
'search-result-category-size' => '{{PLURAL:$1|1 Seitn|$1 Seitn}} ({{PLURAL:$2|1 Untakategorie|$2 Untakategorina}}, {{PLURAL:$3|1 Datei|$3 Datein}})',
'search-redirect' => '(Weidaloatung vo „$1“)',
'search-section' => '(Obschnitt $1)',
'search-suggest' => 'Hädast „$1“ gmoand?',
'search-interwiki-caption' => 'Schwesterprojekte',
'search-interwiki-default' => '$1 Eagebnisse:',
'search-interwiki-more' => '(mea)',
'searchrelated' => 'vawandt',
'searchall' => 'olle',
'showingresultsheader' => "{{PLURAL:$5|Ergebnis '''$1''' vo '''$3'''|Ergebniss '''$1–$2''' vo '''$3'''}} fia '''$4'''",
'nonefound' => "'''Hiwais:''' Es wern standardmässig nur oanige Nåmensraim durchsuacht. Setz ''all:'' vur dain Suachbegrif, um olle Saiten (inkl. Dischkrirsaiten, Vurlong usw.) z' durchsuacha oder züid 'n Nåmen vom z' durchsuachanden Nåmensraum.",
'search-nonefound' => 'Fia dei Suachofrog gibts koa Ergebnis',
'powersearch' => 'Suach',
'powersearch-legend' => 'Daweiterde Suach',
'powersearch-ns' => 'Suach in Nåmensraim:',
'powersearch-redir' => 'Weiderloattung åzoang',
'powersearch-field' => 'Suach noch:',
'search-external' => 'Externe Suach',

# Preferences page
'preferences' => 'Eihstellungen',
'mypreferences' => 'Mei Preferenz',
'changepassword' => 'Posswort ändern',
'prefs-editing' => 'Beorweiten',
'rows' => 'Zeiln:',
'columns' => 'Spoiten',
'searchresultshead' => 'Suachen',
'resultsperpage' => 'Dreffer pró Seiten:',
'savedprefs' => 'Deine Eihstellungen san gspeicherd worn.',
'timezonelegend' => 'Zaidzone:',
'localtime' => 'Ortszaid:',
'timezoneuseserverdefault' => 'Standardzeid vom Wiki nutzen ($1)',
'guesstimezone' => 'Vom Browser ywernemmer',
'allowemail' => 'E-Mail-Empfång voh anderne Benutzer méglé mochen.',
'prefs-searchoptions' => 'Suachopziónen',
'prefs-namespaces' => 'Nåmensraim',
'youremail' => 'E-Mail-Adress:',
'username' => 'Benutzernåm:',
'yourrealname' => 'Biagalicha Nama:',
'yourlanguage' => 'Sprooch vo da Benutzerowerflächen',
'prefs-help-realname' => 'Opzionoi. Dodamid kå dai byrgerlicher Nåm daine Baiträg zuagordnet wern.',
'prefs-help-email' => 'De Mail-Adress is optional; es is oba sinnvoi, wensd es Passwort amoi vagessn hosd.',
'prefs-help-email-others' => 'Andane Nutza kenan so aa mit dia Kontakt afnehma, duach an E-Mail-Link auf da Navi vo da Nutzaseitn.
Dei Mail-Adress wead dabei ned ozoagt.',
'prefs-help-email-required' => 'Es werd a güitige E-Mäil-Adress braucht.',
'prefs-info' => 'Baasisinformazionen',

# User rights
'userrights-groupsmember' => 'Midgliad vo:',
'userrights-no-interwiki' => 'Du hast koa Berechtigung, Benutzerrechte in anderne Wikis zum ändern.',

# Groups
'group-sysop' => 'Administratorn',
'group-bureaucrat' => 'Byrókraaten',
'group-suppress' => 'Oversighter',
'group-all' => '(olle)',

'group-user-member' => '{{GENDER:$1|Benutzer|Benutzerrin}}',
'group-autoconfirmed-member' => '{{GENDER:$1|Autómaatisch bstätigter Benutzer|Autómaatisch bstätigter Benutzerrin}}',
'group-bot-member' => 'Bot',
'group-sysop-member' => '{{GENDER:$1|Administraator|Administraatorin}}',
'group-bureaucrat-member' => '{{GENDER:$1|Byrókraat|Byrókraatin}}',
'group-suppress-member' => '{{GENDER:$1|Oversighter|Oversighterrin}}',

'grouppage-user' => '{{ns:project}}:Benutzer',
'grouppage-autoconfirmed' => '{{ns:project}}:Autómaatisch bstätigte Benutzer',
'grouppage-bot' => '{{ns:project}}:Bots',
'grouppage-sysop' => '{{ns:project}}:Administraatorn',
'grouppage-bureaucrat' => '{{ns:project}}:Byrókraaten',
'grouppage-suppress' => '{{ns:project}}:Oversighter',

# Rights
'right-read' => 'Seiten leesen',
'right-edit' => 'Seiten beorweiten',
'right-block' => 'Benutzer sperrn (Schreiwrecht)',

# Special:Log/newusers
'newuserlogpage' => 'Neiomejdungs-Logbuach',

# User rights log
'rightslog' => 'Rechte-Logbiache',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'beorbadd de Seitn',
'action-createpage' => "Seiten z' dastön",
'action-autopatrol' => 'eigerne Beorweitungen ois kontroilird markirn',

# Recent changes
'nchanges' => '$1 {{PLURAL:$1|Endarung|Endarunga}}',
'recentchanges' => 'Letzte Endarunga',
'recentchanges-legend' => 'Ozoagoptiona',
'recentchanges-summary' => "Auf derer Seiten kåst d' létzden Änderrungen auf '''{{SITENAME}}''' nochévavóing.",
'recentchanges-feed-description' => 'Vafoig mid em Feed de letztn Endarunga in {{SITENAME}}.',
'recentchanges-label-newpage' => 'Neiche Seitn',
'recentchanges-label-minor' => 'Kloane Endarunga',
'recentchanges-label-bot' => 'Endarung duach an Bot',
'recentchanges-label-unpatrolled' => 'De Endarung is no ned kontrolliad worn',
'rcnote' => "{{PLURAL:$1|'''1''' Endarung|'''$1''' Endarunga}} in dn {{PLURAL:$2|letztn 24 Stundn|letztn '''$2'''Dog}}.
Stand: $4, $5 Uhr.",
'rcnotefrom' => "Untn san de Endarunga seit  '''$2''' (bis za '''$1''' Ozoagn).",
'rclistfrom' => 'Nua Endarunga seit $1 zoagn.',
'rcshowhideminor' => 'Kloane Endarunga $1',
'rcshowhidebots' => 'Bots $1',
'rcshowhideliu' => 'Eigloggte Nutza $1',
'rcshowhideanons' => 'Anonyme Nutza $1',
'rcshowhidepatr' => 'Kontrolliade Endarunga $1',
'rcshowhidemine' => 'Meine Beidreg $1',
'rclinks' => 'De letztn Endarunga vo de letztn $2 Dog zoagn<br />$3',
'diff' => 'Untaschied',
'hist' => 'Versiona',
'hide' => 'Ausblendn',
'show' => 'Zoag',
'minoreditletter' => 'K',
'newpageletter' => 'N',
'boteditletter' => 'B',
'number_of_watching_users_pageview' => '[$1 {{PLURAL:$1|beówochtender|beówochtende}} Benutzer]',
'rc_categories' => 'Netter Seiten aus d\' Kategorien (trennd mid "l"):',
'rc_categories_any' => 'Olle',
'newsectionsummary' => 'Neicher Obschnit /* $1 */',
'rc-enhanced-expand' => 'Details zoagn (braucht JavaScript)',
'rc-enhanced-hide' => 'Details vastecka',

# Recent changes linked
'recentchangeslinked' => 'Endarunga an Valinkunga',
'recentchangeslinked-feed' => 'Valinkts priaffm',
'recentchangeslinked-toolbox' => 'Endarunga af valinktn Seitn',
'recentchangeslinked-title' => 'Endarunga wo vo „$1“ valinkt san',
'recentchangeslinked-summary' => "Des is a Listn vo de letztn Endarunga af Seitn, de wo vo ana bstimmtn Seitn valinkt san (bzw. za ana bstimmtn Kategorie ghean).
Seitn af [[Special:Watchlist|deina Beobochtungslistn]] san '''fett'''.",
'recentchangeslinked-page' => 'Seitn:',
'recentchangeslinked-to' => 'Zoagt Änderrungen auf Seiten, dé do her valinken',

# Upload
'upload' => 'Affelodn',
'uploadbtn' => 'Daatei aufféloon',
'uploadnologin' => 'Néd ågmödt',
'uploadnologintext' => 'Du muasst [[Special:UserLogin|ågmödt]] seih, wånn Du Daatein auffeloon wüst.',
'uploadlog' => 'Daatei-Logbiache',
'uploadlogpage' => 'Logbuach fias Affelodn',
'uploadlogpagetext' => 'Des is des Logbuach voh de auffegloodanen Daatein, schaug aa unter [[Special:NewFiles|neiche Daatein]].',
'filename' => 'Daateinåm',
'filedesc' => 'Bschreiwung',
'fileuploadsummary' => 'Bschreiwung/Quön',
'filereuploadsummary' => 'Daateiänderrungen:',
'filestatus' => 'Copyright-Staatus:',
'filesource' => 'Quön:',
'uploadedfiles' => 'Aufféglooderne Daatein',
'ignorewarning' => "D' Warnung ignoriern und d' Daatei speichern",
'ignorewarnings' => 'Warnung ignoriern',
'minlength1' => 'Dé Daateinaumen miassen minderstens aan Buachstom laung seih.',
'badfilename' => 'Da Daateinåm is auf „$1“ gänderd worn.',
'large-file' => 'De Daateigreess soidad noch Meeglichkeid $1 ned ywerschreiten. De Daatei is $2 grooss.',
'largefileserver' => 'Dé Daatei is greesser ois dé vom Server eihgstöde Maximaalgreessen.',
'emptyfile' => 'Dé aufféglooderne Daatei is laar. Da Grund kauh a Tippfeeler im Daateinaum seih. Bittscheh kóntróllier, ób du dé Daatei wirklé aufféloon wüst.',
'uploadwarning' => 'Ówocht',
'savefile' => 'Daatei speichern',
'uploadedimage' => 'hod „[[$1]]“ affeglodn',
'uploaddisabled' => "'s aufféloon is deaktivierd",
'uploadscripted' => 'Dé Datei enthoit HTML- óder Scriptcode, der wos irrtymlicherweis voram Webbrowser ausgfyrd wern kunnterd.',
'uploadvirus' => 'Dé Daatei do enthoitt a Virus! Details: $1',
'upload-source' => 'Quödaatei',
'sourcefilename' => 'Quödaatei:',
'sourceurl' => 'Quön-URL:',
'destfilename' => 'Zünaum:',
'upload-maxfilesize' => 'Maximaale Daateigréss: $1',
'upload-description' => 'Daateibschreiwung',
'upload-options' => 'Ópziónen fyrs Aufféloon',
'watchthisupload' => 'Dé Seiten beówochten',
'filewasdeleted' => "A Daatei mid dém Naum is schoh oamoi auffégloon und zwischenzeidlé wieder gléschd worn. Bittscheh schaug erscht 'n Eihtrog im $1 auh, bevur du dé Daatei wirklé speicherdst.",
'upload-success-subj' => 'Erfóigreich auffégloon',
'upload-failure-subj' => 'A Feeler beim Aufféloon',
'upload-warning-subj' => 'Auffélood-Warnung',

'upload-file-error' => 'Interner Feeler',
'upload-unknown-size' => 'Néd bekaunnte Greess',

# img_auth script messages
'img-auth-accessdenied' => 'Zuagrieff vaweigerd',

# Some likely curl errors. More could be added from <http://curl.haxx.se/libcurl/c/libcurl-errors.html>
'upload-curl-error6' => "D' URL is néd dareichbor",

'license' => 'Lizenz:',
'license-header' => 'Lizenz',
'nolicense' => 'koah Vurauswoi',
'license-nopreview' => '(es gibt koah Vurschau)',
'upload_source_file' => ' (a Daatei auf deim Computer)',

# Special:ListFiles
'listfiles_search_for' => 'Suach noch da Daatei:',
'imgfile' => 'Daatei',
'listfiles' => 'Daateilisten',
'listfiles_thumb' => 'Vurschaubüdel',
'listfiles_date' => 'Daatum',
'listfiles_name' => 'Nåm',
'listfiles_user' => 'Benutzer',
'listfiles_size' => 'Greess',
'listfiles_description' => 'Bschreiwung',
'listfiles_count' => 'Versiónen',

# File description page
'file-anchor-link' => 'Datei',
'filehist' => 'Dateiversiona',
'filehist-help' => 'Klick auf an Zeitpunkt, um de Version ozschaugn.',
'filehist-revert' => 'zrucksetzn',
'filehist-current' => 'aktuell',
'filehist-datetime' => 'Version vom',
'filehist-thumb' => 'Vorschaubuidl',
'filehist-thumbtext' => 'Vorschaubuidl fia d Version vo $1',
'filehist-user' => 'Nutza',
'filehist-dimensions' => 'Dimensiona',
'filehist-filesize' => 'Dateigreess',
'filehist-comment' => 'Kommentar',
'imagelinks' => 'Dateivawendung',
'linkstoimage' => '{{PLURAL:$1|De foigende Seitn vawendt|De foigendn $1 Seitn vawendn}} de Datei:',
'linkstoimage-more' => "Es {{PLURAL:$1|valinkt|valinkn}} mea wia {{PLURAL:$1|oa Seitn |$1 Seitn}} auf de Datei.
De foignde Listn zaagt netta {{PLURAL:$1|in easten Link|de easten $1 Links}} auf de Datei.
A [[Special:WhatLinksHere/$2|voiständige Listn]] gibt's aa.",
'nolinkstoimage' => 'De Datei wead vo koana Seitn gnutzt.',
'morelinkstoimage' => '[[Special:WhatLinksHere/$1|Weidare Links]] fia de Datei.',
'duplicatesoffile' => "{{PLURAL:$1|D'foignde Datei is a Duplikat|De foigndn $1 Datein han Duplikate}} vu dea Datei ([[Special:FileDuplicateSearch/$2|weidare Deteus]]):",
'sharedupload' => 'De Datei stãmmt aus $1 und deaf bei ãndare Projekte vawendt wean.',
'sharedupload-desc-there' => "De Datei stãmmt aus $1 und deaf bei ãndera Projekte vawendt wean. Schau auf'd [$2 Dateibeschreibungsseitn] fia weidare Infoamazionen.",
'sharedupload-desc-here' => 'De Datei stammt aus $1 und deaf vo andan Projektn vawendt wean. De Bschreibung vo da [$2 Dateibschreibungsseitn] wead unen ozoagt.',
'uploadnewversion-linktext' => 'A neiche Versión voh derer Daatei aufféloon',

# File reversion
'filerevert-defaultcomment' => 'zruckgsétzd auf dé Versión vom $1, $2',
'filerevert-submit' => 'Zrucksetzen',

# File deletion
'filedelete-legend' => 'Lésch dé Daatei',
'filedelete-intro' => "Du léschst dé Daatei '''„[[Media:$1|$1]]“'''.",

# MIME search
'mimesearch-summary' => 'Auf dieser Spezialseite können die Dateien nach dem MIME-Typ gefiltert werden. Die Eingabe muss immer den Medien- und Subtyp beinhalten: <code>image/jpeg</code> (siehe Bildbeschreibungsseite).',
'download' => 'Owerlooden',

# Unused templates
'unusedtemplates' => 'Net benutzte Vorlagen',
'unusedtemplateswlh' => 'Aundre Links',

# Random page
'randompage' => 'Zuafoisseitn',

# Statistics
'statistics' => 'Statistik',
'statistics-articles' => 'Inhoidsseiten',
'statistics-pages' => 'Seiten',
'statistics-pages-desc' => 'Olle Seiten in dém Wiki, inklusiav da Dischkrirseiten, Weiderloatungen usw.',
'statistics-files' => 'Aufféglooderne Daatein',
'statistics-edits' => 'Seitenbeorweitungen',
'statistics-edits-average' => 'Beorweitungen pró Seiten im Durchschnit',
'statistics-views-total' => 'Seitenaufruaff gsåmmt',
'statistics-mostpopular' => 'Dé am moastbsuachten Seiten',

'doubleredirects' => 'Doppede Weiderloatungen',

'brokenredirects-edit' => 'werkeln',
'brokenredirects-delete' => 'léschen',

'withoutinterwiki' => 'Seiten óne an Link zua åndre Sproochen',
'withoutinterwiki-summary' => "D' foiganden Seiten valinken néd auf a åndre Sproochversion",
'withoutinterwiki-legend' => 'Präfix',
'withoutinterwiki-submit' => 'Zoag',

'fewestrevisions' => "Seiten mid d' weenigsten Versiónen",

# Miscellaneous special pages
'nbytes' => '$1 {{PLURAL:$1|Byte}}',
'ncategories' => '$1 {{PLURAL:$1|Kategorie|Kategorien}}',
'nlinks' => '{{PLURAL:$1|a Link|$1 Links}}',
'nmembers' => '{{PLURAL:$1|1 Eindrog|$1 Eindreg}}',
'nrevisions' => '{{PLURAL:$1|oah Beorwatung|$1 Beorwatungen}}',
'nviews' => '{{PLURAL:$1|1 Åbfråg|$1 Åbfrång}}',
'uncategorizedpages' => 'Néd kategorisirde Seiten',
'uncategorizedcategories' => 'Néd kategorisirde Kategorien',
'uncategorizedimages' => 'Néd kategorisirde Daatein',
'uncategorizedtemplates' => 'Néd kategorisirde Vurlong',
'unusedcategories' => 'Néd bnutzde Kategorien',
'unusedimages' => 'Néd bnutzde Daatein',
'popularpages' => 'Dé bliabtersten Seiten',
'wantedcategories' => 'Bnutzde, ower néd åglégte Kategorien',
'wantedpages' => 'Gwynschde Seiten',
'wantedpages-badtitle' => 'Ungütiger Titel im Ergeewnis: $1',
'wantedfiles' => 'Fööhernde Daatein',
'wantedtemplates' => 'Fööhernde Vurlong',
'mostlinked' => 'Haiffig valinkte Seiten',
'mostlinkedcategories' => 'Haiffig brauchde Kategorien',
'mostlinkedtemplates' => 'Haiffig brauchde Vurlong',
'mostcategories' => 'Seiten mid dé haiffigsten Kategorien',
'mostimages' => 'Haiffig brauchde Daatein',
'mostrevisions' => "Seiten mid d' haiffigsten Versiónen",
'prefixindex' => 'Olle Seien (mit Präfix)',
'shortpages' => 'Kurze Seiten',
'longpages' => 'Långe Seiten',
'deadendpages' => 'Néd valinkende Seiten',
'deadendpagestext' => 'Dé fóigénden Seiten vaweisen néd auf aundre Seiten voh {{SITENAME}}.',
'protectedpages' => 'Gschytzde Seiten',
'protectedpages-indef' => 'Netter néd bschränkde gschytzde Seiten zoang',
'protectedpages-cascade' => 'Netter Seiten mid Kaskadenschutz',
'protectedtitles' => 'Gschytzde Seitennaumen',
'usercreated' => '{{GENDER:$3|Oglegt}} am $1 um $2',
'newpages' => 'Neiche Seitn',
'newpages-username' => 'Benutzernåm:',
'ancientpages' => 'Schoh länger nimmer beorweitade Seiten',
'move' => 'Vaschiabm',
'movethispage' => 'de Seiten vaschiam',
'notargettitle' => 'Koa Seiten ågeem',
'pager-newer-n' => '{{PLURAL:$1|naxta|naxte $1}}',
'pager-older-n' => '{{PLURAL:$1|vorheriga|vorherign $1}}',

# Book sources
'booksources' => 'ISBN-Suach',
'booksources-search-legend' => 'Suach noch Bezugsquejn fia Biacha',
'booksources-go' => 'Suach',

# Special:Log
'log' => 'Logbiacha',
'all-logs-page' => 'Olle effmtlichen Logbiacher',
'alllogstext' => 'Des is de kombinierte Anzeige vo alle in {{SITENAME}} gführten Logbiacha. Die Ausgabe ko durch de Auswahl vom Logbuchtyp, vom Benutzer oder vom Seitntitel eigschränkt wern.',
'logempty' => 'Koane passenden Einträg.',
'log-title-wildcard' => 'Da Titel faungt auh mid ....',

# Special:AllPages
'allpages' => 'Olle Seitn',
'alphaindexline' => '$1 bis $2',
'nextpage' => 'Naxde Seiten ($1)',
'prevpage' => 'Vurherige Seiten ($1)',
'allpagesfrom' => 'Seiten auhzoang ob:',
'allpagesto' => 'Seiten auhzoang bis:',
'allarticles' => 'Olle Seitn',
'allinnamespace' => 'Olle Seiten (Naumensraum: $1)',
'allnotinnamespace' => 'Ollte Seiten  (néd im $1 Naumensraum)',
'allpagesprev' => 'Vurige',
'allpagesnext' => 'Naxde',
'allpagessubmit' => 'Owendn',
'allpagesprefix' => 'Seiten zoang mid Präfix:',
'allpagesbadtitle' => "Da eihgeewerne Seitennaum is néd gütig: Er hod éntwéder a vurauhgstöds Sprooch-, a Interwiki-Kyrzel óder enthoitt oah óder mererne Zeichen, dé in d' Seitennaumen néd vawendt wern derffm.",
'allpages-bad-ns' => 'Dén Naumensraum „$1“ gibts in {{SITENAME}} néd.',

# Special:Categories
'categories' => 'Kategorina',
'special-categories-sort-count' => 'Sortiarung noch da Auhzoi',
'special-categories-sort-abc' => "Sortiarung noch 'm Alfabet",

# Special:DeletedContributions
'deletedcontributions' => 'Gléschde Beitrég',

# Special:LinkSearch
'linksearch' => 'Weblinks suacher',
'linksearch-pat' => 'Suachmuster:',
'linksearch-ns' => 'Nåmensraum:',
'linksearch-ok' => 'Suacher',
'linksearch-text' => "Dé Speziaalseiten do daméglicht d' Suach noch Seiten, in dénen bstimmte Weblinks enthoiden san. Dodabei kennern Blootzhoiter wia beispüsweis  <code>*.beispü.at</code> hergnummer wern. Es muass mindastens a Top-Level-Domain, z. Bsp. „*.org“. auhgeem wern. <br />Unterstytzde Protokói: <code>$1</code> (Dé bittscheh bei da Suachauhgob auhgeem.)",
'linksearch-line' => '$1 is valinkt vo $2',

# Special:ListUsers
'listusers-submit' => 'Zoag',
'listusers-noresult' => 'Koane Benutzer gfunden.',

# Special:ListGroupRights
'listgrouprights' => 'Benutzergruppmrechtt',
'listgrouprights-summary' => 'Dés do is a Listen voh dé in dém Wiki definierden Benutzergruppm und da dodamid vabundernen Rechtt.
Zuasätzlige Informaziónen ywer dé oahzelnen Rechtt kennan [[{{MediaWiki:Listgrouprights-helppage}}|do]] gfunden wern.',
'listgrouprights-key' => '* <span class="listgrouprights-granted">Gwärds Recht</span>
* <span class="listgrouprights-revoked">Entzóngs Recht</span>',
'listgrouprights-group' => 'Gruppm',
'listgrouprights-rights' => 'Rechte',
'listgrouprights-helppage' => 'Help:Gruppmrechte',
'listgrouprights-members' => '(Mitgliedalistn)',
'listgrouprights-addgroup' => 'Benutzer zua {{PLURAL:$2|derer Gruppm|dé Gruppm}} dazuadoah: $1',
'listgrouprights-removegroup' => 'Benutzer aus {{PLURAL:$2|derer Gruppm|dé Gruppm}} entferner: $1',
'listgrouprights-addgroup-all' => 'Benutzer zua olle Gruppm dazuadoah',
'listgrouprights-removegroup-all' => 'Benutzer aus olle Gruppm éntferner',
'listgrouprights-addgroup-self' => "'s oagerne Benutzerkóntó zua {{PLURAL:$2|derer Gruppm|dé Gruppm}} dazuadoah: $1",
'listgrouprights-removegroup-self' => "'s oagerne Benutzerkóntó aus {{PLURAL:$2|derer Gruppm|dé Gruppm}} entferner: $1",
'listgrouprights-addgroup-self-all' => 'Kauh olle Gruppm zum oagern Kóntó dazuadoah',

# Email user
'mailnologin' => 'Du bist néd auhgmödt',
'emailuser' => 'Mail an den Nutza',
'emailpage' => 'E-Mail aun Benutzer',
'noemailtitle' => 'Koah E-Mail-Adress',
'emailfrom' => 'Voh:',
'emailto' => 'Aun:',
'emailsubject' => 'Bedreff:',
'emailmessage' => 'Noochricht:',
'emailsend' => 'Senden',
'emailccme' => 'Schick a Kópie voh da E-Mail aun mi söwer',
'emailccsubject' => 'a Kópie voh deiner Noochricht an $1: $2',
'emailsent' => 'E-Mail is vaschickt worn',
'emailsenttext' => 'Deih E-Mail is vaschickt worn.',
'emailuserfooter' => 'Dé E-Mail is voh {{SITENAME}}-Benutzer „$1“ an „$2“ gsendt worn.',

# User Messenger
'usermessage-summary' => 'Systémnoochricht gspeicherd.',
'usermessage-editor' => 'Systém-Messenger',

# Watchlist
'watchlist' => 'Beobochtungslistn',
'mywatchlist' => 'Mei Beobochta',
'watchlistfor2' => 'Vo $1 $2',
'nowatchlist' => 'Es gibt koane Eihträg auf deiner Beówochtungslisten.',
'watchlistanontext' => "Du muasst dé $1, um deih Beówchtungslisten z' seeng óder Eihträg borweiten z' kenner.",
'watchnologin' => 'Du bist néd auhgmödt',
'watchnologintext' => "Du muasst [[Special:UserLogin|auhgmödt]] seih, um deih Beówochtungslisten beorweiten z' kenner.",
'addwatch' => 'Zua Beówochtungslisten dazuadoah',
'addedwatchtext' => 'Dé Seiten „[[:$1]]“ is zua deiner [[Special:Watchlist|Beówochtungslisten]] dazuadauh worn.
Änderrungen an derer Seiten und voh da Dischkrierseiten wern do glistt und in da Ywersicht voh dé [[Special:RecentChanges|létzden Änderrungen]] auf Fettschrieft auhzoagt.

Waunnst dé Seiten wieder voh deiner Beówochtungslisten weggerddoah mechst, druck oafoch auf da jeeweiling Seiten auf „nimmer beówochten“.',
'removewatch' => 'Voh da Beówochtungslisten wegdoah',
'removedwatchtext' => "D' Seiten „[[:$1]]“ is voh deiner [[Special:Watchlist|Beówochtungslisten]] wegdauh worn.",
'watch' => 'Beobochtn',
'watchthispage' => "D' Seiten beówochten",
'unwatch' => 'nimma beobochtn',
'unwatchthispage' => 'Nimmer beówochten',
'notanarticle' => 'Koah Seiten',
'notvisiblerev' => 'Versión is gléschd worn',
'watchlist-details' => 'Du beoochst {{PLURAL:$1|$1 Seitn}}, Dischkriaseitn ned mitgrechnad',
'wlheader-enotif' => 'Da E-Mail-Benoochrichtigungsdeanst is aktivierd.',
'wlheader-showupdated' => "Seiten mid noh néd gseengne Änderrungen wern '''fett''' dorgstöd.",
'watchmethod-recent' => "Ywerpriaff d' létzden Beorwatungen fyr d' Beówochtungslisten",
'watchmethod-list' => 'Ywerpriaffm voh da Beówochtungslisten auf létzde Beorwatungen',
'watchlistcontains' => 'Deih Beówochtungslisten enthoitt $1 {{PLURAL:$1|Seiten|Seiten}}.',
'iteminvalidname' => 'Próblém mim Eihtrog „$1“, néd gütiger Naum.',
'wlnote' => "Es {{PLURAL:$1|fóigt d' létzde Änderrung|fóing d' létzden '''$1''' Änderrungen}} voh da/dé {{PLURAL:$2|Stund| '''$2''' Stunden}}. Staund: $3, $4 Uar.",
'wlshowlast' => 'Zoag dé Änderrungen voh dé létzden $1 Stunden, $2 Dog óder $3 (in dé létzden 30 Dog).',
'watchlist-options' => 'Mei Beobochta: Optiona',

# Displayed when you click the "watch" button and it is in the process of watching
'watching' => 'Beówochten ...',
'unwatching' => 'Néd Beówochten',
'watcherrortext' => 'Ban Ändern voh da Beówochtungslisten fyr „$1“ is a Feeler auftreeden.',

'enotif_mailer' => '{{SITENAME}}-E-Mail-Benoochrichtigungsdeanst',
'enotif_reset' => 'Olle Seiten ois bsuacht markiern',
'enotif_impersonal_salutation' => '{{SITENAME}}-Benutzer',
'enotif_lastvisited' => 'Olle Änderrungen auf oan Blick: $1',
'enotif_lastdiff' => 'Schaug auf $1 noch derer Änderrung.',
'enotif_anon_editor' => 'Anonymer Benutzer $1',
'enotif_body' => 'Servas $WATCHINGUSERNAME,

dé {{SITENAME}}-Seiten „$PAGETITLE“ is voh $PAGEEDITOR am $PAGEEDITDATE um $PAGEEDITTIME Uar $CHANGEDORCREATED.

Aktuöe Versión: $PAGETITLE_URL

$NEWPAGE

Zåmmfossung vom Beorweiter: $PAGESUMMARY $PAGEMINOREDIT

Kontakt zum Beorweiter:
E-Mail: $PAGEEDITOR_EMAIL
Wiki: $PAGEEDITOR_WIKI

Es wern da sólång koane weidern Benoochrichtigungsmails gsendt, bis du dé Seiten wieder bsuachst. Auf deiner Beówochtungslisten kåst olle Benoochrichtigunsmarkiarungen zåmm zrucksétzen.
             Deih freindlichs {{SITENAME}}-Benoochrichtigungssystém

--
Um d\' Eihstöungen voh da E-Mail-Benoochrichtigung åzpassen, bsuachst {{canonicalurl:{{#special:Preferences}}}}

Um d\' Eihstöungen voh deine Beówochtungslisten åzpassen, bsuachst {{canonicalurl:{{#special:EditWatchlist}}}}

Um d\' Seiten voh deiner Beówochtungslisten ower z\' doah, bsuachst $UNWATCHURL

Ryckmödungen und a weidre Hüf: {{canonicalurl:{{MediaWiki:Helppage}}}}',
'created' => 'erstöd',
'changed' => 'gänderd',

# Delete
'deletepage' => 'Seiten léschen',
'confirm' => 'Bstäting',
'excontent' => "Oider Inhoid: '$1'",
'excontentauthor' => 'Da Inhoid is gwésen: „$1“ (oahziger Beorweiter: [[Special:Contributions/$2|$2]])',
'exbeforeblank' => 'Da Inhoid vurm Laarn voh da Seiten: „$1“',
'exblank' => "D' Seiten is laar gwén",
'delete-confirm' => 'Léschen voh „$1“',
'delete-legend' => 'Léschen',
'historywarning' => "'''Ochtung:''' Dé Seiten, dé du léschen mecherst, hod a Versiónsgschicht mid epper $1 {{PLURAL:$1|Versión|Versiónen}}:",
'confirmdeletetext' => "Du bist dabei, a Seiten mid olle zuaghering ödern Versiónen z' léschen. Bittscheh bstätig dodazua, daas da d' Kónsequenzen bewusst san und daas du in Ywereihstimmung mid d' [[{{MediaWiki:Policy-url}}|Richtlinien]] haundelst.",
'actioncomplete' => 'Aktion beendt',
'actionfailed' => 'Akzion fejgschlogn',
'deletedtext' => '„$1“ is glöscht worn. Im $2 findn Sie a Listn vo de letzten Löschungen.',
'dellogpage' => 'Lesch-Logbuach',
'deletionlog' => 'Lösch-Logbuach',
'reverted' => 'Auf a oide Version zruckgesetzt',
'deletecomment' => 'Grund:',
'deleteotherreason' => 'Ånderner/ergänzender Grund:',
'deletereasonotherlist' => 'Åndrer Grund:',
'deletereason-dropdown' => '* Oigmoane Léschgrynd
** Wunsch vom Autór
** Urhéwerrechtsvalétzung
** Vandalismus',
'delete-edit-reasonlist' => 'Léschgrynd beorwaten',

# Rollback
'rollbacklink' => 'Zrucksetzn',
'rollbackfailed' => 'Zruckésétzen gscheiterd',
'cantrollback' => "D' Änderrung kauh néd zruckégsétzd wern, weis koane friarern Autorn gibt.",

# Protect
'protectlogpage' => 'Seitnschutz-Logbuach',
'protectedarticle' => 'hod „[[$1]]“ gschitzt',
'modifiedarticleprotection' => 'hod an Schutz voh „[[$1]]“ gänderd',
'unprotectedarticle' => 'Schutz voh „[[$1]]“ aufghóm',
'prot_1movedto2' => 'hod [[$1]] noch [[$2]] vaschóm',
'protect-legend' => 'Seitenschutzstaatus ändern',
'protectcomment' => 'Grund:',
'protectexpiry' => 'Sperrdauer:',
'protect_expiry_invalid' => "D' eihgéwerne Dauer is ungütig",
'protect_expiry_old' => "D' Sperrzeid liegt in da Vagångenheit.",
'protect-text' => "Då kãnnst nåchschau und ändan, wia d'Seitn „$1“ gschützt is.",
'protect-locked-access' => "Dai Benytzerkonto vafiagt ned ywer de notwending Rechtt zur Endarung vom Saitenschutz. Do san de aktuöin Saitenschutzaistöiungen vo da Saiten '''„$1“:'''",
'protect-cascadeon' => 'De Saiten is geengwärtig a Tail vo ner Kaskadenperrn. Sii is in de {{PLURAL:$1|folgende Seite|foiganden Saiten}} aibunden, de durch de Kaskadensperropzion geschytzt {{PLURAL:$1|ist|san}}. Der Saitenschutzstaatus vo derer Saiten kå gändert wern, des hod ower koan Aifluss auf de Kaskadensperrn:',
'protect-default' => 'Olle Benutzer',
'protect-fallback' => "D'„$1“-Berechtigung is notwendig.",
'protect-level-autoconfirmed' => 'Sperrung fyr néd registrirde Benutzer',
'protect-level-sysop' => 'Netter Administraatorn',
'protect-summary-cascade' => 'kaskadiarnd',
'protect-expiring' => 'bis zum $2 um $3 Uhr (UTC)',
'protect-cascade' => 'Kaskadiarade Sperr – ålle Voalång, de in dea Seitn eibundn han, wean emfåis gspead.',
'protect-cantedit' => "Du kãnnst de Spea vu dea Seitn ned ändan, weu'st dafia ned de passnde Berechtigung håst.",
'protect-expiry-options' => '1 Stund:1 hour,1 Dog:1 day,1 Wóch:1 week,2 Wócher:2 weeks,1 Mónad:1 month,3 Mónadt:3 months,6 Mónadt:6 months,1 Jor:1 year, Unbschränkt:infinite',
'restriction-type' => 'Schutzstaatus:',
'restriction-level' => 'Schutzheechen:',
'minimum-size' => 'Mindestgreess',

# Restrictions (nouns)
'restriction-edit' => 'Werkeln',
'restriction-move' => 'vaschiam',

# Undelete
'undelete' => 'Gléschde Seiten weiderherstön',
'undeletehistorynoadmin' => 'Dé Seiten is gléscht worn. Da Léschgrund is in da Zaummfossung auhgeem, 
genauasó wia Details zum létzden Benutzer, der dé Seiten vur da Léschung borweidt hod.
Da aktuöje Text voh da gléschden Seiten is netter fyr Administraatorn zuagänglich.',
'undelete-revision' => 'Geléschde Versión voh $1 (vom $4 um $5 Uar), $3:',
'undeletebtn' => 'Wiederherstön',
'undeletelink' => 'oschaugn / wiadaheastejn',
'undeleteviewlink' => 'oschaugn',
'undeletereset' => 'Zrucksétzen',
'undeletedfiles' => '$1 {{plural:$1|Datei|Dateien}} san wieda hergstellt worn',
'undelete-search-box' => 'Suach noch gléschde Seiten',
'undelete-search-submit' => 'Suach',
'undelete-show-file-submit' => 'Jo',

# Namespace form on various pages
'namespace' => 'Namasramm:',
'invert' => 'Auswoi umdraan',
'namespace_association' => 'Zuagordnéter Nåmensraum',
'blanknamespace' => '(Seitn)',

# Contributions
'contributions' => '{{GENDER:$1|Nutza}}beidreg',
'contributions-title' => 'Nutzabeidräg vo „$1“',
'mycontris' => 'Meine Beidreg',
'contribsub2' => 'Vo $1 ($2)',
'uctop' => '(aktuell)',
'month' => 'und Monad:',
'year' => 'Bis zan Joar:',

'sp-contributions-newbies' => 'Nua Beidräg vo de neichn Nutza ozoagn',
'sp-contributions-newbies-sub' => 'Fyr Neiling',
'sp-contributions-blocklog' => 'Sperrlogbuach',
'sp-contributions-deleted' => 'Gléschde Beitrég',
'sp-contributions-uploads' => 'Affeglodane Datein',
'sp-contributions-logs' => 'Logbiacha',
'sp-contributions-talk' => 'Dischkrian',
'sp-contributions-search' => 'Suach noch Nutzabeidräg',
'sp-contributions-username' => 'IP-Adress oda Nutzanama:',
'sp-contributions-toponly' => 'Nua aktuelle Versiona ozoagn',
'sp-contributions-submit' => 'Suachn',

# What links here
'whatlinkshere' => 'Links af de Seitn',
'whatlinkshere-title' => 'Seitn, wo af „$1“ valinka',
'whatlinkshere-page' => 'Seitn:',
'linkshere' => "De foigandn Seitn valinka af '''„[[:$1]]“''':",
'nolinkshere' => "Koa Seitn valinkt af '''„[[:$1]]“'''.",
'isredirect' => 'Weidaloatungsseitn',
'istemplate' => 'Vorlogneinbindung',
'isimage' => 'Dateilink',
'whatlinkshere-prev' => '{{PLURAL:$1|vorige|vorign $1}}',
'whatlinkshere-next' => '{{PLURAL:$1|naxde|naxdn $1}}',
'whatlinkshere-links' => '← Vaweise',
'whatlinkshere-hideredirs' => 'Weidaloatunga $1',
'whatlinkshere-hidetrans' => 'Vorlognehbindung $1',
'whatlinkshere-hidelinks' => 'Links $1',
'whatlinkshere-hideimages' => '$1 Dateilinks',
'whatlinkshere-filters' => 'Fuita',

# Block/unblock
'autoblockid' => 'Autómaatische Sperrung #$1',
'block' => 'Benutzer sperrn',
'unblock' => 'Benutzer freigeem',
'blockip' => 'IP-Adress/Benytzer sperrn',
'blockip-title' => 'Benytzer sperrn',
'blockip-legend' => 'IP-Adresse/Benutzer sperrn',
'blockiptext' => "Mid dem Formular sperrst a IP-Adress oder an Benytzernåmen, das vo durten aus koane Endarungen mer vurgnumma wern kennan.
Des soid nur dafoing, um an Vandalismus z' vahindern und in Yweraistimmung mid d' [[{{MediaWiki:Policy-url}}|Richtlinien]].
Gib bittschee an Grund fyr d' Sperrn å.",
'ipadressorusername' => 'IP-Adress oder Benytzernåm:',
'ipbexpiry' => 'Sperrdauer:',
'ipbreason' => 'Grund:',
'ipbreasonotherlist' => 'Åndarer Grund:',
'ipbreason-dropdown' => '* Oigmoahne Sperrgrynd
** Eihfyng voh voische Informaziónen
** Laarn voh Seiten
** Massenweiss Eihfyng voh externe Links
** Eihstön voh unsinnige Inhoite auf Seiten
** néd åbrochts Vahoiden
** Missbrauch mid mererne Benutzerkontós
** néd geigneter Benutzernåm',
'ipb-hardblock' => 'Auhgmödte Benutzer dodrauh hindern, daas Beorweitungen unter derer IP-Adress vurgnummer wern',
'ipbcreateaccount' => "D' Erstöung voh Benutzerkóntós vahindern",
'ipbemailban' => 'E-Mail-Vasånd sperrn',
'ipbenableautoblock' => "Sperr dé aktuö voh dém Benutzer gnutzde IP-Adress sówia autómaatisch olle fóiganden, voh dénen aus er Beorweitungen óder 's Auhléng voh Benutzerkóntós vasuacht.",
'ipbsubmit' => 'IP-Adress/Benutzer sperrn',
'ipbother' => 'Åndre Dauer (auf englisch):',
'ipboptions' => '2 Stund:2 hours,1 Dog:1 day,3 Dog:3 days,1 Woch:1 week,2 Wocha:2 weeks,1 Monat:1 month,3 Monat:3 months,6 Monat:6 months,1 Joar:1 year, Infinit:infinite',
'ipbotheroption' => 'Åndre Dauer:',
'ipbotherreason' => 'Ånderner/ergenznder Grund:',
'ipbhidename' => 'An Benytzernåmen in Beorwaitungen und Linsten vastecken',
'ipbwatchuser' => 'De Benytzer(diskussions)saiten beowochten',
'ipb-change-block' => "D' Sperrn mid de Sperrparameter danaiern",
'badipaddress' => 'De IP-Adress hod a foischs Format.',
'blockipsuccesssub' => 'De Sperrn is erfoigraich gween',
'blockipsuccesstext' => 'Da Benytzer/de IP-Adress [[Special:Contributions/$1|$1]] is gsperrt worn.<br />
Zur da Aufheewung vo da Sperrn schau unter da [[Special:BlockList|Listen vo olle aktivm Sperrn]].',
'ipb-edit-dropdown' => 'Sperrgrynd beorwaiten',
'ipb-unblock-addr' => '„$1“ fraigeem',
'ipb-unblock' => 'IP-Adress/Benytzer fraigeem',
'ipb-blocklist' => 'Olle aktuöin Sperrn åzaang',
'ipb-blocklist-contribs' => 'Benytzerbaiträg vo „$1“',
'unblockip' => 'IP-Adress fraigeem',
'unblockiptext' => 'Mid dem Formular do kååst du a IP-Adress oder an Benytzer fraigeem.',
'ipusubmit' => 'Freigem',
'unblocked' => '[[User:$1|$1]] is freigem worn',
'unblocked-id' => 'Sperr-ID $1 is fraigeem worn',
'ipblocklist' => 'Gsperrte Nutza',
'ipblocklist-legend' => 'Suach noch am gsperrden Benytzer',
'createaccountblock' => "'s erstön voh Benutzerkóntós is gsperrd",
'emailblock' => 'E-Póst vaschicker is gsperrd',
'blocklink' => 'Sperrn',
'unblocklink' => 'Freigebm',
'change-blocklink' => 'Sperr endan',
'contribslink' => 'Beidreg',
'emaillink' => 'E-Póst schicker',
'autoblocker' => 'Autómaatische Sperr, wei du a gmoahsaume IP-Adress mim [[User:$1|$1]] bnutzd. Grund voh da Benutzersperrn: „$2“.',
'blocklogpage' => 'Sperrlogbuach',
'blocklog-showlog' => "{{GENDER:$1|Der Benutzer|Dé Benutzerrin|Der Benutzer}} do is schoh friarer gsperrd worn. Es fóigt a Eihtrog aus'm Benutzersperrlogbiaché:",
'blocklog-showsuppresslog' => "{{GENDER:$1|Der Benutzer|Dé Benutzerrin|Der Benutzer}} do is schoh friarer gsperrd und vastéckt worn. Es fóigt a Eihtrog aus'm Benutzersperrlogbiaché:",
'blocklogentry' => 'hod „[[$1]]“ gsperrt bis: $2; $3',
'reblock-logentry' => "hod d' Sperrn voh „[[$1]]“ fyrn Zeidraum: $2 $3 gänderd.",
'unblocklogentry' => "hod d' Sperr voh „$1“ aufghóm",
'block-log-flags-anononly' => 'netter Anónyme',
'block-log-flags-nocreate' => 'Es Olegn vo Nutzakontn is gsperrt',
'block-log-flags-noautoblock' => 'Autóblóck deaktivierd',
'block-log-flags-noemail' => 'E-Post vaschicka gspead',

# Developer tools
'unlockdb' => 'Daatenbaunk freigeem',
'unlockconfirm' => 'Ja, i mecht de Datenbank freigem.',
'unlockbtn' => 'Datenbank freigem',
'locknoconfirm' => 'Sie ham des Bestätigungsfeld net markiert.',
'lockfilenotwritable' => "Die Datenbank-Sperrdatei ist net beschreibbar. Zum Sperrn oda Freigem vo da Datenbank muaß de für'n Webserver beschreibbar sei.",
'databasenotlocked' => 'De Datenbank is net gsperrt.',

# Move page
'move-page-legend' => 'Seiten vaschiam',
'movepagetext' => "Mid dém Formular kauhst a Seiten umbenénner, waunnstas mid olle Versiónen auf an neichen Titel vaschiabst.
Da oide Titel werd danoch zum neichen weiderloaten.
Du kauhst Weiderloatungen, dé auf dén Originoititel valinken, autómaatisch koarigiern lossen.
Stö sicher, daas du im Auhschlus olle [[Special:DoubleRedirects|dóppéden]] óder [[Special:BrokenRedirects|dé hienigen Weiderloatungen]] ywerpriaffst.
Du bist dodafyr vaauntwortlich, daas Links weiderhih aufs richtige Zü vaweisen.

Dé Seiten werd '''néd''' vaschóm, waunns bereits a Seiten mim vurgseegernen Titel gibt, ausser dé is laar óder a Weiderloatung óne a Versiónsgschicht. 
Dés bdeitt, daas du d' Umbenénnung ryckgängig mochen kauhst, waunn du an Feeler gmocht host.  Du kauhst hihgéng koah Seiten ywerschreim.

'''Ówocht!'''
D' Vaschiawung kauh weidreichende und néd daworterde Fóing fyr haiffig bsuachde Seiten haum.
Du sóiderst désswéng d' Kónsequenzen vastaunden haum, bevur du iatz weider duast.",
'movepagetalktext' => "De dazuaghearade Dischgria-Seitn wiad, fåis's ane gibt, midvaschom, '''außa'''
*unta'm neichn Nãm gibt's schãu an Eintråg oda
*du tuast s'Hakal bei da unting Opzion außa.

In de zwoa Fälle miaßadst, fåis des gwünscht is, de Seitn händisch vaschiam oda zsãmmfüng.

Bittschee gib außadem druntn in '''neichn''' Nãm vu da Seitn ei und schreib kuaz '''wieso'''<nowiki>'st</nowiki> de Seitn vaschiam mechst.",
'movearticle' => 'Seitn vaschiam:',
'movenologin' => 'Du bist néd ågmödt',
'movenologintext' => 'Zum Vaschiam muaßt a registriada und [[Special:UserLogin|ãngmöideta Benutza]] sei.',
'movenotallowed' => 'Du håst ka Berechtigung zum Vaschiam vu Seitn.',
'movenotallowedfile' => 'Du håst ka Berechtigung zum Vaschiam vu Datein.',
'cant-move-user-page' => 'Du håst ka Berechtigung zum Vaschiam vu Benutzahauptseitn.',
'cant-move-to-user-page' => 'Du håst ka Berechtigung zum Vaschiam vu Seitn auf a Benutzaseitn (Ausnãhmen han Benutza-Untaseitn).',
'newtitle' => 'Züi:',
'move-watch' => "D' Seiten beówochten",
'movepagebtn' => 'Seitn vaschiam',
'pagemovedsub' => "s'Vaschiam håd highaud",
'movepage-moved' => "'''D'Seitn „$1“ is nåch „$2“ vaschom woan.'''",
'movepage-moved-redirect' => 'Es is a Weiderloatung erstöd worn.',
'articleexists' => 'Unter dém Naum existierd schoh a Seiten. Bittscheh nimm an aundern Naumen her.',
'talkexists' => "D' Seiten söwer is erfóigreich vaschóm worn, ower d' zuagherige Dischkrierseiten néd, weis mid dém Titel schoh oane gibt. Bittscheh kymmerd dé händisch ums zaummfyrn.",
'movedto' => 'vaschóm auf',
'movetalk' => "Waunns geet, d' Dischkrierseiten aa midvaschiam",
'movelogpage' => 'Vaschiabungs-Logbuach',
'movereason' => 'Grund:',
'revertmove' => 'zruck vaschiabm',
'delete_and_move' => 'Löschn und vaschiam',
'delete_and_move_reason' => 'glöscht, um Plåtz fia Vaschiam zum macha',
'selfmove' => 'Ursprungs- und Zielname sand gleich; a Seitn kann net auf sich selber verschom wern.',

# Export
'export' => 'Seitn exportian',

# Namespace 8 related
'allmessagesname' => 'Nama:',
'allmessagesdefault' => 'Standardtext',
'allmessagescurrent' => 'Aktuella Text',
'allmessagestext' => 'Des is a Listen vo de MediaWiki-Systemtextt.
Bsuach bittschee de Saiten [//www.mediawiki.org/wiki/Localisation MediaWiki-Lokalisiarung] und [//translatewiki.net translatewiki.net], wånn du de ån da Lokalisiarung vo MediaWiki betailing mechadst.',
'allmessagesnotsupportedDB' => "'''Special:Allmessages''' is im Moment net möglich, wei de Datenbank offline is.",

# Thumbnails
'thumbnail-more' => 'vagressan',
'thumbnail_error' => 'Fehla ban Estejn vom Vorschaubuidl: $1',

# Special:Import
'importnotext' => 'Laar oder koa Text',

# Import log
'importlogpage' => 'Import-Logbuach',

# Tooltip help for the actions
'tooltip-pt-userpage' => 'Dei Nutzaseitn',
'tooltip-pt-mytalk' => 'Dei Dischkriaseitn',
'tooltip-pt-preferences' => 'Deine Preferenzn',
'tooltip-pt-watchlist' => 'A Listn vo Seitn, wos du beobochtest',
'tooltip-pt-mycontris' => 'A Listn vo de oagna Beidreg',
'tooltip-pt-login' => 'Warad schee, wensd di omejdn dadast, es is oba ned zwingend nedig.',
'tooltip-pt-logout' => 'Auslogga',
'tooltip-ca-talk' => 'Dischkrian iban Seitninhoid',
'tooltip-ca-edit' => 'Du konsd de Seitn beorbatn. Bittschee vawendt in Vorschau-Knopf bevorsd speichasd.',
'tooltip-ca-addsection' => 'Neichn Obschnitt ofanga',
'tooltip-ca-viewsource' => 'De Seitn is gschitzd. In Quejtext konsda oschaugn.',
'tooltip-ca-history' => 'Friaare Versiona vo dera Seitn',
'tooltip-ca-protect' => 'Seitn schitzn',
'tooltip-ca-unprotect' => 'Seitenschutz ändern',
'tooltip-ca-delete' => 'De Seitn leschn',
'tooltip-ca-undelete' => 'Eihträg wiederherstön, bevur dé Seiten gléscht worn is.',
'tooltip-ca-move' => 'De Seitn vaschiabm',
'tooltip-ca-watch' => 'De Seitn zua Beobochtungslistn dazua doa',
'tooltip-ca-unwatch' => 'De Seitn vom "Beobochta" wegga doa',
'tooltip-search' => '{{SITENAME}} duachsuacha',
'tooltip-search-go' => 'Geh direkt zua Seitn mit exakt im Nama, wens de gibt.',
'tooltip-search-fulltext' => 'Suach noch Seitn, wo den Text enthoiden',
'tooltip-p-logo' => 'Schau da de Hoamseitn o',
'tooltip-n-mainpage' => 'Schau da de Hoamseitn o',
'tooltip-n-mainpage-description' => 'De Hoamseitn bsuacha',
'tooltip-n-portal' => 'Ibas Projekt, wos d mocha konst, wo wos z findn is',
'tooltip-n-currentevents' => 'Hintergrundinformaziónen ywer akutelle Ereigniss

Hintagrundinfo za Neiigkeidn',
'tooltip-n-recentchanges' => 'A Listn vo de letztn Endarunga in da {{SITENAME}}',
'tooltip-n-randompage' => 'A Zuafoisseitn afruafa',
'tooltip-n-help' => 'Huifseitn ozoagn',
'tooltip-t-whatlinkshere' => 'A Listn vo oin Seitn, wo do hea zoagn',
'tooltip-t-recentchangeslinked' => 'De letztn Endarunga af Seitn, de wo do hea valinka',
'tooltip-feed-rss' => 'RSS-Feed vo derer Saiten',
'tooltip-feed-atom' => 'Atom-Feed vo dera Seitn',
'tooltip-t-contributions' => 'A Listn vo de Nutzabeidreg',
'tooltip-t-emailuser' => 'Em Nutza a Mail schicka',
'tooltip-t-upload' => 'Datein affelodn',
'tooltip-t-specialpages' => 'A Listn vo olle Spezialseitn',
'tooltip-t-print' => 'Druckosicht za dea Seitn',
'tooltip-t-permalink' => 'Dauerhofta Link za dea Seitnversion',
'tooltip-ca-nstab-main' => 'Seitninhoid ozoagn',
'tooltip-ca-nstab-user' => 'Nutzaseitn oschaugn',
'tooltip-ca-nstab-media' => 'Meediendaateiseiten åzoang',
'tooltip-ca-nstab-special' => 'Des is a Spezialseitn, wosd ned beorbatn konst.',
'tooltip-ca-nstab-project' => 'Projektseitn ozoagn',
'tooltip-ca-nstab-image' => 'Dateiseiten ozoagn',
'tooltip-ca-nstab-mediawiki' => 'MediaWiki-Systémtext åzoang',
'tooltip-ca-nstab-template' => 'Vorlog ozoagn',
'tooltip-ca-nstab-help' => 'Huifseitn oozoang',
'tooltip-ca-nstab-category' => 'Kategorieseitn ozoagn',
'tooltip-minoredit' => 'Ois kloane Endarung markian.',
'tooltip-save' => 'Endarunga speichan',
'tooltip-preview' => 'A Vorschau vo de Endarunga an dea Seitn. Vorm Speichan bittschee nutzn!',
'tooltip-diff' => 'Endarunga am Text zoagn',
'tooltip-compareselectedversions' => 'De Untaschied zwischn zwoa Versiona oschaugn.',
'tooltip-watch' => 'De Seitn zua Beobochtungslistn gebm',
'tooltip-recreate' => 'Seitn nei erstelln, obwoi sie glöscht worn is.',
'tooltip-upload' => 'Start as Aufféloon',
'tooltip-rollback' => 'Setzt olle Endarunga zruck, de wo vom gleichn Nutza gmocht worn san.',
'tooltip-undo' => 'Nimmt nua de oane Endarung zruck und eameglicht an Grund ozgebm (Zammfossungszein).',
'tooltip-summary' => 'Gib a kuaze Zammfossung ein',

# Attribution
'lastmodifiedatby' => 'Dé Seiten is zletzt am $1 um $2 voh $3 gänderd worn.',
'othercontribs' => 'Basiard auf da Orweid voh $1',
'creditspage' => 'Seiteninformaziónen',

# Patrolling
'markedaspatrollederrortext' => 'Du muasst a Seitenänderrung auswön',

# Image deletion
'deletedrevision' => 'Oide Version $1 glöscht.',
'filedelete-missing' => 'De Datei „$1“ ko net glöscht wern, weils es net gibt.',

# Browsing diffs
'previousdiff' => '← Zan vorign Versionsuntaschied',
'nextdiff' => 'Zan naxtn Versionsuntaschied →',

# Media information
'file-info-size' => '$1 × $2 Pixel, Dateigress: $3, MIME-Typ: $4',
'file-nohires' => 'Es gibt koa hehare Aflesung.',
'svg-long-desc' => 'SVG-Datei, Basisgress: $1 × $2 Pixl, Dateigress: $3',
'show-big-image' => 'Volle Aflesung',

# Special:NewFiles
'newimages' => 'Neiche Daatein',
'newimages-summary' => "Dé Speziaalseiten zoagt d' zlétzd aufféglooderne Daatei auh.",
'noimages' => 'Koane Daatein gfunden.',
'ilsubmit' => 'Suach',

# Bad image list
'bad_image_list' => 'Format wia foigt:

Nua Zein, de wo mit am * ofanga, wean ausgweatet. 
Da easchte Link in da Zein, muass a Link af a schlechte Datei sei.
Irgendwejche foigandn Links in da sejm Zein definian Ausnahma, z. B. Seitn wo de Datei trotzdem vawendt wean deaf.',

# Metadata
'metadata' => 'Metadatn',
'metadata-help' => 'De Datei enthoit weidane Infos, wo woarscheinli vo da vawendadn Digitalkamera oda Scanna kema.
Wen de Datei vaendat worn is, kena a poar Detail andasta sei.',
'metadata-expand' => 'Erweitate Deteus eiblendn',
'metadata-collapse' => "D' erweiterden Details eihblenden",
'metadata-fields' => 'De foigandn Fejda vo de EXIF-Metadaten, wo im MediaWiki-Systemtext ogebm san, wean auf Buidbschriebseitn mid eikloppta Metadatentabejn ozoagt.
Weidane wean standardmassi ned ozoagt.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# Exif tags
'exif-gpsspeed' => 'Gschwindigkeid vom GPS-Empfänger',

'exif-componentsconfiguration-0' => 'Gibts néd',

# External editor support
'edit-externally' => 'De Datei mid am externa Programm beorbatn',
'edit-externally-help' => '(Schaug unter [//www.mediawiki.org/wiki/Manual:External_editors Installationsoweisunga] fia weidane Infos)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'olle',
'namespacesall' => 'olle',
'monthsall' => 'olle',

# Email address confirmation
'confirmemail' => 'E-Post-Adressn bestäting (Authentifiziarung)',
'confirmemail_noemail' => 'Du håst ka güitige E-Post-Adressn in deine [[Special:Preferences|persönlichn Eistellungen]] eitrång.',
'confirmemail_send' => 'Bstätigungscode zuaschicker',
'confirmemail_needlogin' => "Du muasst dé $1 um d' E-Mail-Adress zum bstäting.",

# Multipage image navigation
'imgmultipageprev' => '← vurige Seiten',
'imgmultipagenext' => 'naxde Seiten →',
'imgmultigo' => 'OK',
'imgmultigoto' => 'Gee zua Seiten $1',

# Table pager
'ascending_abbrev' => 'auf',
'descending_abbrev' => 'ob',
'table_pager_next' => 'Naxde Seiten',
'table_pager_prev' => 'Vurherige Seiten',
'table_pager_first' => 'Erste Seiten',
'table_pager_last' => 'Letzde Seiten',
'table_pager_limit' => 'Zoag $1 Eihträg pró Seiten',
'table_pager_limit_label' => 'Pósiziónen pró Seiten:',
'table_pager_limit_submit' => 'Lós',
'table_pager_empty' => 'Koane Ergeebniss',

# Auto-summaries
'autosumm-blank' => 'Dé Seiten is glaard worn.',
'autosumm-replace' => "Da Seiteninhoid is durch an åndern Text ersétzt worn: '$1'",
'autoredircomment' => 'Weiderloatung noch [[$1]] is erstöd worn',
'autosumm-new' => 'Dé Seiten is neich åglégt worn: $1',

# Size units
'size-bytes' => '$1 Bytes',

# Live preview
'livepreview-loading' => 'Loon ...',
'livepreview-ready' => 'Loon … Ferdig!',
'livepreview-failed' => "Dé sófurtige Vurschau is néd méglich!
Bittscheh d' noraale Vurschau bnutzen.",

# Watchlist editor
'watchlistedit-noitems' => 'Dei Beobachtungslistn is laar.',
'watchlistedit-normal-title' => 'Beobachtungslistn bearbatn',
'watchlistedit-normal-legend' => 'Eiträge vo da Beobachtungslistn wegnehma',
'watchlistedit-normal-explain' => "Des san de Eiträg vo deiner Beowochtungslisten. Um de Eiträg z' entferna, markir de Kastln neem de Eiträg und druck am End vo da Seiten auf „{{int:Watchlistedit-normal-submit}}“. Du kåst dei Beowochtungslisten aa im  [[Special:EditWatchlist/raw|Listenformat beorweiten]].",
'watchlistedit-normal-submit' => 'Eiträge wegnehma',
'watchlistedit-raw-title' => 'Beówochtungslisten im Listenformaat beorweiten',
'watchlistedit-raw-legend' => 'Beówochtungslisten im Listenformaat beorweiten',
'watchlistedit-raw-titles' => 'Eihträg:',
'watchlistedit-raw-submit' => 'Beówochtungslisten aktualisirn',

# Watchlist editing tools
'watchlisttools-view' => 'Mei Beobochta: Endarunga',
'watchlisttools-edit' => 'normal beorbatn',
'watchlisttools-raw' => 'Im Roh-Listnformat beorbatn',

# Signatures
'signature' => '[[{{ns:user}}:$1|$2]] ([[{{ns:user_talk}}:$1|Diskussión]])',

# Core parser functions
'unknown_extension_tag' => 'Unbekaunnter Extension-Tag „$1“',
'duplicate-defaultsort' => 'Obocht: Da Sortiasschlossl "$2" ibaschreibt in friaan Schlissl "$1".',

# Special:Version
'version' => 'Versión',
'version-extensions' => 'Installierde Daweiterrungen',
'version-specialpages' => 'Speziaalseiten',
'version-parserhooks' => 'Parser-Hooks',
'version-variables' => 'Variaablen',
'version-antispam' => 'Spamschutz',
'version-skins' => 'Benutzerówerflächen',
'version-other' => 'Ånders',
'version-mediahandlers' => 'Meediennutzung',
'version-hooks' => "Schnidstön ''(Hooks)''",
'version-parser-extensiontags' => "Parserdaweiterrungen ''(tags)''",
'version-parser-function-hooks' => 'Parserfunkziónen',
'version-hook-name' => 'Schnidstönnaum',
'version-hook-subscribedby' => 'Aufruaff voh',
'version-version' => '(Versión $1)',
'version-license' => 'Lizenz',
'version-poweredby-credits' => "Dé Nétzseiten braucht '''[//www.mediawiki.org/wiki/MediaWiki/de MediaWiki]''', Copyright © 2001–$1 $2.",
'version-poweredby-others' => 'åndre',

# Special:FileDuplicateSearch
'fileduplicatesearch' => 'Dóppéde Daatein suachen',
'fileduplicatesearch-summary' => 'Suach noch dóppéde Daatein auf da Baasis vo eanerm Hash-Wert.',
'fileduplicatesearch-legend' => 'Suach noch Duplikaate',
'fileduplicatesearch-filename' => 'Daateinåm:',
'fileduplicatesearch-submit' => 'Suachen',
'fileduplicatesearch-info' => '$1 × $2 Pixel<br />Daateigress: $3<br />MIME-Typ: $4',
'fileduplicatesearch-result-1' => 'Dé Daatei „$1“ hod koane identischen Duplikaate.',

# Special:SpecialPages
'specialpages' => 'Spezialseitn',
'specialpages-note' => '----
* Reguläre Speziaalseiten
* <span class="mw-specialpagerestricted">Zuagrifsbschränkde Speziaalseiten</span>
* <span class="mw-specialpagecached">Cachegenerrirde Speziaalseiten (Da Inhoid is méglicherweis vaoiterd)</span>',
'specialpages-group-maintenance' => 'Wartungslisten',
'specialpages-group-other' => 'Åndre Speziaalseiten',
'specialpages-group-login' => 'Åmöden',
'specialpages-group-changes' => 'Létzde Änderrungen und Logbiacher',
'specialpages-group-media' => 'Meedien',
'specialpages-group-users' => 'Benutzer und Rechtt',
'specialpages-group-highuse' => 'Haiffig brauchde Seiten',
'specialpages-group-pages' => 'Listen voh Seiten',
'specialpages-group-pagetools' => 'Seitenwerkzeig',
'specialpages-group-wiki' => 'Systémdaaten und Werzeig',
'specialpages-group-redirects' => 'Weiderloattende Speziaalseiten',
'specialpages-group-spam' => 'Spam-Werkzeig',

# Special:BlankPage
'blankpage' => 'Laare Seiten',
'intentionallyblankpage' => 'Dé Seiten is obsichtlich óne an Inhoid. Sie werd fyr Benchmarks vawendt',

# External image whitelist
'external_image_whitelist' => '#De Zein ned vaendan<pre>
#Untahoib kennan Fragment vo reguleare Ausdrick (da Tei zwischn de //) eigebm wean.
#De wean mid de URL vo externa Buidl vaglicha (Hotlinks)
#A positiva Vagleich fiat zua Buidozoag, sonst wead nua a Link zan Buid ozoagt
#Zein, wo mit # ofanga, wean ois Kommentar bhandlt
#Grouss-/Kloaschreibung is irrelevant

#Fragment vo reguleare Ausdrick noch dera Zein eitrong. De Zein ned vaendan</pre>',

# Special:Tags
'tags' => 'Gütige Änderrungsmarkiarunen',
'tag-filter' => '[[Special:Tags|Markiarungs]]-Fuita:',
'tag-filter-submit' => 'Füter',
'tags-title' => 'Markiarungen',
'tags-intro' => 'Dé Seiten zoagt olle Markiarungen, dé fyr Beorweidungen vawendt wern, sówia dé Bedeitung voh dé.',
'tags-tag' => 'Markiarungsnåm',
'tags-display-header' => "Bnénnung auf d' Änderrungslisten",
'tags-description-header' => 'Vóiständige Bschreiwung',
'tags-hitcount-header' => 'Markirde Änderrungen',
'tags-edit' => 'werkeln',
'tags-hitcount' => '$1 {{PLURAL:$1|Änderrung|Änderrungen}}',

# Special:ComparePages
'comparepages' => 'Seiten vagleichen',
'compare-selector' => 'Seitenversiónen vagleichen',
'compare-page1' => 'Seiten 1',
'compare-page2' => 'Seiten 2',
'compare-rev1' => 'Versión 1',
'compare-rev2' => 'Versión 2',
'compare-submit' => 'Vagleichen',
'compare-invalid-title' => 'Da ågeewerne Seitennåm is néd gütig',
'compare-title-not-exists' => 'Da ågeewerne Seitennåm is néd vurhånden',
'compare-revision-not-exists' => 'Dé ågeewerne Versión is néd vurhånden',

# Database error messages
'dberr-header' => 'Dés Wiki hod a Próblém',
'dberr-problems' => 'Tschuidigung. Dé Seiten hod im Moment technische Próbléme.',
'dberr-again' => "Wort a por Minuten und vasuachs dånn neich z' loon.",
'dberr-info' => '(Kå koah Vabindung zum Daatenbånkserver herstön: $1)',
'dberr-usegoogle' => 'Du kunntersd dawei mid Google suachen.',
'dberr-outofdate' => 'Beochtt, daas da Suachindex voh inserne Inhoitt bei Google vaoiterd seih kunnt.',

# HTML forms
'htmlform-required' => 'Der Wert do werd braucht.',
'htmlform-submit' => 'Speichern',
'htmlform-reset' => 'Änderrungen ryckgängég mochen',
'htmlform-selectorother-other' => 'Åndre',

# Search suggestions
'searchsuggest-search' => 'Suach',
'searchsuggest-containing' => 'Voitextsuach noch ...',

);
